package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.AlignSource

Sourcetype t =
  1. | Visible
  2. | Left
  3. | Centered
Sourceval all : t list

all is a list of all alignments.

Sourceval to_string : t -> string

to_string t is the string representation of t.

Sourceval of_string : string -> (t, string) result

of_string s is the alignment represented by s or Error msg if s does not represent any alignment.

Sourceval t_of_yojson : Yojson.Safe.t -> t
Sourceval yojson_of_t : t -> Yojson.Safe.t