package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.LayoutSource

Sourcetype t =
  1. | Tiling
  2. | Scrolling
  3. | Floating
Sourceval all : t list

all is every layout, in cycle order.

Sourceval to_string : t -> string

to_string t is t's name in lowercase.

Sourceval of_string : string -> t option

of_string s is the layout named by s, trimmed and case-insensitive; None when unrecognized.

Sourceval cycle : t -> Direction.Logical.t -> t

cycle t dir is the layout that follows t in dir. Wraps at the ends of all.

Sourceval t_of_yojson : Yojson.Safe.t -> t
Sourceval yojson_of_t : t -> Yojson.Safe.t