package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.MessagesSource

Sourceval seat_missing_output : string

seat_missing_output is the standard error message used when an operation is performed on a seat with no output.

Sourceval no_focused_window : string

no_focused_window is the standard error message used when an operation is performed on a seat with no focused window.

Sourceval window_is_fullscreen : string

window_is_fullscreen is the standard error message used when an invalid operation is performed on a fullscreen window.

Sourceval no_other_output : string

no_other_output is the standard error message used when an operation is performed on an output that doesn't exist.

Sourceval window_missing_output : string

window_missing_output is the standard error message used when an operation is performed on a window that is not attached to any output.

Sourceval tag_set_is_empty : string

tag_set_is_empty is the standard error message used when the given tag set is empty.

Sourceval not_scrolling : string

not_scrolling is the standard error message used when an operation is performed on an output that is not in the Scrolling layout.