package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.ModeSource

Sourcetype t

A keybind mode. A value exists only for a declared mode: resolve and declare are the only constructors.

Sourceval normal : t

normal is the built-in mode every binding belongs to by default.

Sourceval locked : t

locked is the built-in mode in effect while the session is locked.

Sourceval equal : t -> t -> bool
Sourceval to_string : t -> string

to_string mode is the name of mode.

Sourceval resolve : string -> declared:t list -> (t, string) result

resolve name ~declared is the mode in declared named name, or Error msg when no declared mode has name.

Sourceval declare : string -> declared:t list -> (t, string) result

declare name ~declared is a new mode named name, or Error msg when declared already has a mode with name.