package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.PatternSource

Sourcemodule Case : sig ... end
Sourceval re_compile : case:Case.t -> string -> (Re.re, string) result

re_compile ~case s compiles s as a PCRE regex with the case flag of case.

Sourceval matches : case:Case.t -> pattern:string option -> string -> bool

matches ~case ~pattern str is true when pattern is absent, or when its regex matches str. Is false when the regex is malformed, logging an error.

Sourceval compile_specs : case:Case.t -> (string option * ('a -> string list)) list -> ('a -> bool, string) result

compile_specs ~case specs compiles specs into a matching function.