package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.PhysSource

Sourceval opt_equal : 'a option -> 'a option -> bool

opt_equal a b is true when a and b are both None or hold physically equal (==) values.

Sourceval opt_holds : 'a -> 'a option -> bool

opt_holds v o is true when o holds v itself (==).