package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.Pointer_buttonSource

Sourcetype t =
  1. | Key_unknown
  2. | Btn_0
  3. | Btn_1
  4. | Btn_2
  5. | Btn_3
  6. | Btn_4
  7. | Btn_5
  8. | Btn_6
  9. | Btn_7
  10. | Btn_8
  11. | Btn_9
  12. | Btn_left
  13. | Btn_right
  14. | Btn_middle
  15. | Btn_side
  16. | Btn_extra
  17. | Btn_forward
  18. | Btn_back
  19. | Btn_task
Sourceval all : t list

all is the list of all pointer buttons, excluding Key_unknown.

Sourceval of_string : string -> (t, string) result

of_string s is the button whose constructor name is s ("Btn_left"); Error msg when unrecognized.

Sourceval to_string : t -> string

to_string b is b's constructor name.

Sourceval of_int32 : int32 -> t

of_int32 code is the button for Linux input-event code; Key_unknown for any code outside 0x100-0x117.

Sourceval to_int32 : t -> int32

to_int32 b is b's Linux input-event code; Key_unknown is KEY_UNKNOWN (240l).

Sourceval t_of_yojson : Yojson.Safe.t -> t
Sourceval yojson_of_t : t -> Yojson.Safe.t