package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_core.Width_facSource

Sourcetype t
Sourceval of_float : float -> t

of_float f is f clamped to 0.1, 1.0.

Sourceval to_float : t -> float

to_float t is the factor as a float.

Sourceval presets : t list

presets is the preset factors 1/3, 1/2, and 2/3, in ascending order.

Sourceval cycle : t -> t

cycle t is the first preset larger than t. Past the last preset, it wraps to the first.