package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_layout.GapsSource

pre gaps area is area inset by gaps' outer gaps minus half its inner gaps, clamped to a non-negative inset. Layouts compute gapless; gaps are applied only by the arrange pipeline.

Sourceval post : Params.Gaps.t -> int Oxbow_core.Rect.t -> int Oxbow_core.Rect.t

post gaps rect is rect inset by half of gaps' inner gaps.