package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.BindSource

Sourceval install_defaults : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> unit

install_defaults wm seat installs system default keybinds to seat.

Effects: mutates WM state

Sourceval parse_modifier : string -> (int32, string) result

parse_modifier s maps recognized modifier strings to Wayland int32 representations. Recognized strings include:

  • Shift
  • Control
  • Mod1|Alt
  • Mod3
  • Mod4|Super|Logo: i.e., the windows key
  • Mod5
  • None

Any other string returns Error "unrecognized".

Sourceval parse_modifiers : string -> (int32, string) result

parse_modifiers s is the modifier mask for the +-joined modifier names in s. Whitespace around each name is ignored.

list wm seat ~all is the JSON keybinding listing for seat; its name, stored mode, and bindings grouped by declared mode, or for every seat in wm when all is true.

handle wm seat keymap applies the Bind/Unbind keymap.

Effects: mutates WM state