package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.DragSource

Sourceval begin_move : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> Oxbow_state.Window.t -> from_tiled:bool -> unit

begin_move ~from_tiled wm seat window focuses window and begins the pointer move operation on seat. from_tiled records the window's tiled state at the start of the drag.

Effects: mutates WM state

Sourceval begin_resize : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> Oxbow_state.Window.t -> int32 -> unit

begin_resize wm seat window focuses window and begins the pointer resize operation on seat and window.

Effects: mutates WM state

step wm seat carries out the next drag operation step in seat.

Effects: mutates WM state