package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.LabelsSource

window_add wm seat target label adds label to the target windows. Error msg when no window is focused.

Effects: mutates WM state

Sourceval window_remove : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> Oxbow_core.Target.Window.Any.t -> string -> (Yojson.Safe.t option, string) result

window_remove wm seat target label removes label from the target windows. Error msg when no window is focused.

Effects: mutates WM state

output_add wm seat target label adds label to the target outputs. Error msg when target is unresolved.

Effects: mutates WM state

Sourceval output_remove : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> Oxbow_core.Target.Output.Any.t -> string -> (Yojson.Safe.t option, string) result

output_remove wm seat target label removes label from the target outputs. Error msg when target is unresolved.

Effects: mutates WM state