package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.PointerSource

Sourceval handle_position : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> (int32 * int32) -> unit

handle_position wm seat (x, y) updates seat's position to (x, y), seat's focused output, and seat's cursor target. Will focus the window under (x, y) when seat's position changed.

Effects: mutates WM state

Sourceval warp_target : Oxbow_state.Seat.t -> (int32 * int32) option

warp_target seat is Some (x, y), the center of seat's focused window, or None if seat has no focused window.

handle wm seat cmd handles the pointer command, cmd.

Effects: mutates WM state