package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.RecordsSource

to_tags output is a tag record derived from output. Is None when output has no name.

to_window wm window is a window record derived from wm and window.

to_output seat output is an output record derived from seat and output.

to_layout output is a layout record derived from output. Is None when output has no name.

to_mode seat is a mode record derived from seat. Is None when seat

to_focus seat is a focus record derived from seat. Is None when seat has no name.