package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.ScratchpadSource

set wm seat target name sets the target windows scratchpad group to name.

Effects: mutates WM state

clear wm seat target clears the target windows scratchpad group and stashes the windows.

Effects: mutates WM state

Sourceval toggle : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> string -> (Yojson.Safe.t option, string) result

toggle wm seat name displays, or hides the scratchpads matching name on seat's focused output. Is Error msg if no scratchpad matches name or seat has no focused output.

Effects: mutate WM state