package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.TilingSource

arrange wm output tiles all non-floating windows on output according to output's currently viewed tags. Is a no-op if output is displaying a fullscreen window.

Effects: mutates WM state

Sourceval zoom : ?warp:bool -> Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> Oxbow_state.Window.t -> (Yojson.Safe.t option, string) result

zoom ?warp wm seat window promotes window to the top of the stack if it is not already the master. If it is the master, promote and swap with the next window. The payload warp overrides the warp on focus configuration. Is Error msg when seat has no output or focused window, the focused window is not tiled, or no other tiled window exists.

Effects: mutates WM state