package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.Window_requestSource

handle wm window request carries out request on window.

Effects: mutates WM state

toggle_maximize wm seat target toggles maximization on the window target. Is Error msg when the window is fullscreen.

Effects: mutates WM state

toggle_fake_fullscreen wm seat target toggles fake fullscreen on the target windows. Is Error msg when any target window is actually fullscreen.

Effects: mutates WM state

toggle_fullscreen wm seat target toggles fullscreen on the target window. Is Error msg when the target window has no output.

Effects: mutates WM state

Sourceval move_interactive : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> (Yojson.Safe.t option, string) result

move_interactive wm seat begins a pointer move of seat's hovered window. Is Error msg when called during an active operation, there is no hovered window, or hovered window is fullscreen.

Effects: mutates WM state

Sourceval resize_interactive : Oxbow_state.Wm.t -> Oxbow_state.Seat.t -> (Yojson.Safe.t option, string) result

resize_interactive wm seat begins a pointer resize of seat's hovered window from its bottom-right. Is Error msg when called during an active operation, there is no hovered window, or hovered window is fullscreen.

Effects: mutates WM state