package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.Window_rulesSource

Sourceval apply_for : Oxbow_state.Wm.t -> Oxbow_state.Window.t -> unit

apply_for wm window applies any configured rules matching window. For rules of the same effect the last rule wins.

Effects: mutates WM state

add wm rule adds rule to wm's configured rules. Merges new rule effects when an existing rule matches rule's pattern.

Effects: mutates WM state

Sourceval remove : Oxbow_state.Wm.t -> int list -> (Yojson.Safe.t option, string) result

remove wm indices removes the rules at the given indices from wm's configured rules. Is Error msg when no rule matches.

Effects: mutates WM state

spawn_for wm window resolves the spawn position and the focus flag for window.