package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_ops.Window_scopeSource

filter wm seat scope is the window list of wm, narrowed to scope. Focused uses the output of seat. An unknown output name is an error.

Sourceval holds : (title:string option -> app_id:string option -> identifier:string option -> labels:string list -> bool) -> Oxbow_state.Window.t -> bool

holds matches window is matches applied to window.

matching wm seat m is the compiled pattern matcher m and a filtered list of matching windows. Is Error msg if m fails to compile, or m is scoped to an unknown output.