package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_libinput_accel_config_v1Source

Acceleration config.

The result returned by libinput on setting configuration for a device.

Sourcetype 'v t = ([ `River_libinput_accel_config_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end
Sourcemodule Accel_type : sig ... end

Version 1

Sourceval set_points : ([< `V1 ] as 'a) t -> [[ `River_libinput_result_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> type_:Imports.River_libinput_accel_config_v1.Accel_type.t -> step:string -> points:string -> ([ `River_libinput_result_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Define custom acceleration function.

Defines the acceleration function for a given movement type in an acceleration configuration with custom accel profile.

Sourceval destroy : [< `V1 ] t -> unit

Destroy the accel object.

This request indicates that the client will no longer use the accel config object and that it may be safely destroyed.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.