package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_libinput_config_v1Source

Libinput config global interface.

Global interface for configuring libinput devices. This global should only be advertised if river_input_manager_v1 is advertised as well.

Sourcetype 'v t = ([ `River_libinput_config_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1, 2

Sourceval create_accel_config : ([< `V1 | `V2 ] as 'a) t -> [[ `River_libinput_accel_config_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> profile:Imports.River_libinput_device_v1.Accel_profile.t -> ([ `River_libinput_accel_config_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Create a acceleration config.

Create a acceleration config which can be applied with river_libinput_device_v1.apply_accel_config.

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the river_libinput_config_v1 object.

This request should be called after the finished event has been received to complete destruction of the object.

It is a protocol error to make this request before the finished event has been received.

If a client wishes to destroy this object it should send a river_libinput_config_v1.stop request and wait for a river_libinput_config_v1.finished event. Once the finished event is received it is safe to destroy this object and any other objects created through this interface.

Sourceval stop : [< `V1 | `V2 ] t -> unit

Stop sending events.

This request indicates that the client no longer wishes to receive events on this object.

The Wayland protocol is asynchronous, which means the server may send further events until the stop request is processed. The client must wait for a river_libinput_config_v1.finished event before destroying this object.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.