package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_libinput_device_v1.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 | `V2 ]
method private virtual on_removed : [> `V1 | `V2 ] t -> unit

The libinput device is removed.

This event indicates that the libinput device has been removed.

The server will send no further events on this object and ignore any request (other than river_libinput_device_v1.destroy) made after this event is sent. The client should destroy this object with the river_libinput_device_v1.destroy request to free up resources.

method private virtual on_input_device : [> `V1 | `V2 ] t -> device: ([ `River_input_device_v1 ], [> Imports.River_input_device_v1.versions ], [ `Client ]) Proxy.t -> unit

Corresponding river input device.

The river_input_device_v1 corresponding to this libinput device. This event will always be the first event sent on the river_libinput_device_v1 object, and it will be sent exactly once.

method private virtual on_send_events_support : [> `V1 | `V2 ] t -> modes:Imports.River_libinput_device_v1.Send_events_modes.t -> unit

Supported send events modes.

Supported send events modes.

method private virtual on_send_events_default : [> `V1 | `V2 ] t -> mode:Imports.River_libinput_device_v1.Send_events_modes.t -> unit

Default send events mode.

Default send events mode.

method private virtual on_send_events_current : [> `V1 | `V2 ] t -> mode:Imports.River_libinput_device_v1.Send_events_modes.t -> unit

Current send events mode.

Current send events mode.

method private virtual on_tap_support : [> `V1 | `V2 ] t -> finger_count:int32 -> unit

Tap-to-click/drag support.

The number of fingers supported for tap-to-click/drag. If finger_count is 0, tap-to-click and drag are unsupported.

method private virtual on_tap_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Tap_state.t -> unit

Default tap-to-click state.

Default tap-to-click state.

method private virtual on_tap_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Tap_state.t -> unit

Current tap-to-click state.

Current tap-to-click state.

method private virtual on_tap_button_map_default : [> `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Tap_button_map.t -> unit

Default tap-to-click button map.

Default tap-to-click button map.

method private virtual on_tap_button_map_current : [> `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Tap_button_map.t -> unit

Current tap-to-click button map.

Current tap-to-click button map.

method private virtual on_drag_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_state.t -> unit

Default tap-and-drag state.

Default tap-and-drag state.

method private virtual on_drag_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_state.t -> unit

Current tap-and-drag state.

Current tap-and-drag state.

method private virtual on_drag_lock_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_lock_state.t -> unit

Default drag lock state.

Default drag lock state.

method private virtual on_drag_lock_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_lock_state.t -> unit

Current drag lock state.

Current drag lock state.

method private virtual on_three_finger_drag_support : [> `V1 | `V2 ] t -> finger_count:int32 -> unit

Three finger drag support.

The number of fingers supported for three/four finger drag. If finger_count is less than 3, three finger drag is unsupported.

method private virtual on_three_finger_drag_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Three_finger_drag_state.t -> unit

Default three finger drag state.

Default three finger drag state.

method private virtual on_three_finger_drag_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Three_finger_drag_state.t -> unit

Current three finger drag state.

Current three finger drag state.

method private virtual on_calibration_matrix_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for a calibration matrix.

A calibration matrix is supported if the supported argument is non-zero.

method private virtual on_calibration_matrix_default : [> `V1 | `V2 ] t -> matrix:string -> unit

Default calibration matrix.

Default calibration matrix.

method private virtual on_calibration_matrix_current : [> `V1 | `V2 ] t -> matrix:string -> unit

Current calibration matrix.

Current calibration matrix.

method private virtual on_accel_profiles_support : [> `V1 | `V2 ] t -> profiles:Imports.River_libinput_device_v1.Accel_profiles.t -> unit

Supported acceleration profiles.

Supported acceleration profiles.

method private virtual on_accel_profile_default : [> `V1 | `V2 ] t -> profile:Imports.River_libinput_device_v1.Accel_profile.t -> unit

Default acceleration profile.

Default acceleration profile.

method private virtual on_accel_profile_current : [> `V1 | `V2 ] t -> profile:Imports.River_libinput_device_v1.Accel_profile.t -> unit

Current acceleration profile.

Current acceleration profile.

method private virtual on_accel_speed_default : [> `V1 | `V2 ] t -> speed:string -> unit

Default acceleration speed.

Default acceleration speed.

method private virtual on_accel_speed_current : [> `V1 | `V2 ] t -> speed:string -> unit

Current acceleration speed.

Current acceleration speed.

method private virtual on_natural_scroll_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for natural scroll.

Natural scroll is supported if the supported argument is non-zero.

method private virtual on_natural_scroll_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Natural_scroll_state.t -> unit

Default natural scroll.

Default natural scroll.

method private virtual on_natural_scroll_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Natural_scroll_state.t -> unit

Current natural scroll state.

Current natural scroll.

method private virtual on_left_handed_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for left-handed mode.

Left-handed mode is supported if the supported argument is non-zero.

method private virtual on_left_handed_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Left_handed_state.t -> unit

Default left-handed mode.

Default left-handed mode.

method private virtual on_left_handed_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Left_handed_state.t -> unit

Current left-handed mode state.

Current left-handed mode.

method private virtual on_click_method_support : [> `V1 | `V2 ] t -> methods:Imports.River_libinput_device_v1.Click_methods.t -> unit

Supported click methods.

The click methods supported by the device.

method private virtual on_click_method_default : [> `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Click_method.t -> unit

Default click method.

Default click method.

method private virtual on_click_method_current : [> `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Click_method.t -> unit

Current click method.

Current click method.

method private virtual on_clickfinger_button_map_default : [> `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Clickfinger_button_map.t -> unit

Default clickfinger button map.

Default clickfinger button map. Supported if click_methods.clickfinger is supported.

method private virtual on_clickfinger_button_map_current : [> `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Clickfinger_button_map.t -> unit

Current clickfinger button map.

Current clickfinger button map. Supported if click_methods.clickfinger is supported.

method private virtual on_middle_emulation_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for middle mouse button emulation.

Middle mouse button emulation is supported if the supported argument is non-zero.

method private virtual on_middle_emulation_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Middle_emulation_state.t -> unit

Default middle mouse button emulation.

Default middle mouse button emulation.

method private virtual on_middle_emulation_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Middle_emulation_state.t -> unit

Current middle mouse button emulation state.

Current middle mouse button emulation.

method private virtual on_scroll_method_support : [> `V1 | `V2 ] t -> methods:Imports.River_libinput_device_v1.Scroll_methods.t -> unit

Supported scroll methods.

The scroll methods supported by the device.

method private virtual on_scroll_method_default : [> `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Scroll_method.t -> unit

Default scroll method.

Default scroll method.

method private virtual on_scroll_method_current : [> `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Scroll_method.t -> unit

Current scroll method.

Current scroll method.

method private virtual on_scroll_button_default : [> `V1 | `V2 ] t -> button:int32 -> unit

Default scroll button.

Default scroll button. Supported if scroll_methods.on_button_down is supported.

method private virtual on_scroll_button_current : [> `V1 | `V2 ] t -> button:int32 -> unit

Current scroll button.

Current scroll button. Supported if scroll_methods.on_button_down is supported.

method private virtual on_scroll_button_lock_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Scroll_button_lock_state.t -> unit

Default scroll button lock state.

Default scroll button lock state. Supported if scroll_methods.on_button_down is supported.

method private virtual on_scroll_button_lock_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Scroll_button_lock_state.t -> unit

Current scroll button lock state.

Current scroll button lock state. Supported if scroll_methods.on_button_down is supported.

method private virtual on_dwt_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for disable-while-typing.

Disable-while-typing is supported if the supported argument is non-zero.

method private virtual on_dwt_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwt_state.t -> unit

Default disable-while-typing state.

Default disable-while-typing state.

method private virtual on_dwt_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwt_state.t -> unit

Current disable-while-typing state.

Current disable-while-typing state.

method private virtual on_dwtp_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for disable-while-trackpointing.

Disable-while-trackpointing is supported if the supported argument is non-zero.

method private virtual on_dwtp_default : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwtp_state.t -> unit

Default disable-while-trackpointing state.

Default disable-while-trackpointing state.

method private virtual on_dwtp_current : [> `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwtp_state.t -> unit

Current disable-while-trackpointing state.

Current disable-while-trackpointing state.

method private virtual on_rotation_support : [> `V1 | `V2 ] t -> supported:int32 -> unit

Support for rotation.

Rotation is supported if the supported argument is non-zero.

method private virtual on_rotation_default : [> `V1 | `V2 ] t -> angle:int32 -> unit

Default rotation angle.

Default rotation angle.

method private virtual on_rotation_current : [> `V1 | `V2 ] t -> angle:int32 -> unit

Current rotation angle.

Current rotation angle.

method private virtual on_done : [> `V2 ] t -> unit

All information has been sent.

This event is sent after all information about the libinput device has been sent.

This allows changes to one or more river_libinput_device_v1 properties to be seen as atomic, even if they happen via multiple events.

method min_version : int32