package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Management.River_input_device_v1Source

An input device.

An input device represents a physical keyboard, mouse, touchscreen, or drawing tablet tool. It is assigned to exactly one seat at a time. By default, all input devices are assigned to the default seat.

Sourcetype 'v t = ([ `River_input_device_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end
Sourcemodule Type : sig ... end

Version 1

Sourceval map_to_rectangle : [< `V1 | `V2 ] t -> x:int32 -> y:int32 -> width:int32 -> height:int32 -> unit

Map input device to the given rectangle.

Map the input device to the given rectangle in the global compositor coordinate space. Has no effect if the device is not a pointer, touch, or tablet device.

If mapped to both an output and a rectangle, the rectangle has priority.

Width and height must be greater than or equal to 0.

Passing 0 for width or height clears an existing mapping.

Sourceval map_to_output : [< `V1 | `V2 ] t -> output:([ `Wl_output ], 'a, [ `Client ]) Wayland.Proxy.t option -> unit

Map input device to the given output.

Map the input device to the given output. Has no effect if the device is not a pointer, touch, or tablet device.

If mapped to both an output and a rectangle, the rectangle has priority.

Passing null clears an existing mapping.

Sourceval set_scroll_factor : [< `V1 | `V2 ] t -> factor:Wayland.Fixed.t -> unit

Set scroll factor.

Set the scroll factor for a pointer input device. Has no effect if the device is not a pointer.

For example, a factor of 0.5 will make scrolling twice as slow while a factor of 3.0 will make scrolling 3 times as fast.

Setting a scroll factor less than 0 is a protocol error.

Sourceval set_repeat_info : [< `V1 | `V2 ] t -> rate:int32 -> delay:int32 -> unit

Set keyboard repeat rate and delay.

Set repeat rate and delay for a keyboard input device. Has no effect if the device is not a keyboard.

Negative values for either rate or delay are illegal. A rate of zero will disable any repeating (regardless of the value of delay).

Sourceval assign_to_seat : [< `V1 | `V2 ] t -> name:string -> unit

Assign the input device to a seat.

Assign the input device to a seat. All input devices not explicitly assigned to a seat are considered assigned to the default seat.

Has no effect if a seat with the given name does not exist.

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the input device object.

This request indicates that the client will no longer use the input device object and that it may be safely destroyed.

Version 2

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.