package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_input_device_v1.v2Source

Handler for a proxy with version >= 2.

constraint 'a = [< `V2 ]
method private virtual on_removed : [> `V2 ] t -> unit

The input device is removed.

This event indicates that the input device has been removed.

The server will send no further events on this object and ignore any request (other than river_input_device_v1.destroy) made after this event is sent. The client should destroy this object with the river_input_device_v1.destroy request to free up resources.

method private virtual on_type : [> `V2 ] t -> type_:Imports.River_input_device_v1.Type.t -> unit

The type of the input device.

The type of the input device. This event is sent once when the river_input_device_v1 object is created. The device type cannot change during the lifetime of the object.

method private virtual on_name : [> `V2 ] t -> name:string -> unit

The name of the input device.

The name of the input device. This event is sent once when the river_input_device_v1 object is created. The device name cannot change during the lifetime of the object.

method private virtual on_done : [> `V2 ] t -> unit

All information has been sent.

This event is sent after all information about the input device has been sent.

This allows changes to one or more river_input_device_v1 properties to be seen as atomic, even if they happen via multiple events.

method min_version : int32