package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Management.River_input_manager_v1Source

Input manager global interface.

Input manager global interface.

Sourcetype 'v t = ([ `River_input_manager_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1, 2

Sourceval destroy_seat : [< `V1 | `V2 ] t -> name:string -> unit

Destroy a seat.

Destroy the seat with the given name. Has no effect if a seat with the given name does not exist.

The default seat with name "default" cannot be destroyed and attempting to destroy it will have no effect.

Any input devices assigned to the destroyed seat at the time of destruction are assigned to the default seat.

Sourceval create_seat : [< `V1 | `V2 ] t -> name:string -> unit

Create a new seat.

Create a new seat with the given name. Has no effect if a seat with the given name already exists.

The default seat with name "default" always exists and does not need to be explicitly created.

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the river_input_manager_v1 object.

This request should be called after the finished event has been received to complete destruction of the object.

It is a protocol error to make this request before the finished event has been received.

If a client wishes to destroy this object it should send a river_input_manager_v1.stop request and wait for a river_input_manager_v1.finished event. Once the finished event is received it is safe to destroy this object and any other objects created through this interface.

Sourceval stop : [< `V1 | `V2 ] t -> unit

Stop sending events.

This request indicates that the client no longer wishes to receive events on this object.

The Wayland protocol is asynchronous, which means the server may send further events until the stop request is processed. The client must wait for a river_input_manager_v1.finished event before destroying this object.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.