package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Layer_shell.River_layer_shell_output_v1Source

Layer shell output state.

The lifetime of this object is tied to the corresponding river_output_v1. This object is made inert when the river_output_v1.removed event is sent and should be destroyed.

Sourcetype 'v t = ([ `River_layer_shell_output_v1 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1

Sourceval set_default : [< `V1 ] t -> unit

Set default output for layer surfaces.

Mark this output as the default for new layer surfaces which do not request a specific output themselves. This request overrides any previous set_default request on any river_layer_shell_output_v1 object.

If no set_default request is made or if the default output is destroyed, the default output is undefined until the next set_default request.

This request modifies window management state and may only be made as part of a manage sequence, see the river_window_manager_v1 description.

Sourceval destroy : [< `V1 ] t -> unit

Destroy the object.

This request indicates that the client will no longer use the river_layer_shell_output_v1 object and that it may be safely destroyed.

This request should be made after the river_output_v1.removed event is received to complete destruction of the output.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.