package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Layer_shell.River_layer_shell_seat_v1Source

Layer shell seat state.

The lifetime of this object is tied to the corresponding river_seat_v1. This object is made inert when the river_seat_v1.removed event is sent and should be destroyed.

Sourcetype 'v t = ([ `River_layer_shell_seat_v1 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1

Sourceval destroy : [< `V1 ] t -> unit

Destroy the object.

This request indicates that the client will no longer use the river_layer_shell_seat_v1 object and that it may be safely destroyed.

This request should be made after the river_seat_v1.removed event is received to complete destruction of the seat.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.