package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Layer_shell.River_layer_shell_v1Source

River layer shell global interface.

This global interface should only be advertised to the client if the river_window_manager_v1 global is also advertised. Binding this interface indicates that the window manager supports layer shell.

If the window manager does not bind this interface, the compositor should not allow clients to map layer surfaces. This can be achieved by closing layer surfaces immediately.

Sourcetype 'v t = ([ `River_layer_shell_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1

Sourceval get_seat : ([< `V1 ] as 'a) t -> [[ `River_layer_shell_seat_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> seat:([ `River_seat_v1 ], 'b, [ `Client ]) Wayland.Proxy.t -> ([ `River_layer_shell_seat_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Get layer shell seat state.

It is a protocol error to make this request more than once for a given river_seat_v1 object.

Sourceval get_output : ([< `V1 ] as 'a) t -> [[ `River_layer_shell_output_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> output:([ `River_output_v1 ], 'b, [ `Client ]) Wayland.Proxy.t -> ([ `River_layer_shell_output_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Get layer shell output state.

It is a protocol error to make this request more than once for a given river_output_v1 object.

Sourceval destroy : [< `V1 ] t -> unit

Destroy the river_layer_shell_v1 object.

This request indicates that the client will no longer use the river_layer_shell_v1 object.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.