package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_libinput_device_v1Source

A libinput device.

In general, *_support events will be sent exactly once directly after the river_libinput_device_v1 is created. *_default events will be sent after *_support events if the config option is supported, and *_current events willl be sent after the *_default events and again whenever the config option is changed.

Sourcetype 'v t = ([ `River_libinput_device_v1 ], 'v, [ `Server ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end
Sourcemodule Send_events_modes : sig ... end
Sourcemodule Tap_state : sig ... end
Sourcemodule Tap_button_map : sig ... end
Sourcemodule Drag_state : sig ... end
Sourcemodule Drag_lock_state : sig ... end
Sourcemodule Three_finger_drag_state : sig ... end
Sourcemodule Accel_profile : sig ... end
Sourcemodule Accel_profiles : sig ... end
Sourcemodule Natural_scroll_state : sig ... end
Sourcemodule Left_handed_state : sig ... end
Sourcemodule Click_method : sig ... end
Sourcemodule Click_methods : sig ... end
Sourcemodule Clickfinger_button_map : sig ... end
Sourcemodule Middle_emulation_state : sig ... end
Sourcemodule Scroll_method : sig ... end
Sourcemodule Scroll_methods : sig ... end
Sourcemodule Scroll_button_lock_state : sig ... end
Sourcemodule Dwt_state : sig ... end
Sourcemodule Dwtp_state : sig ... end

Version 1

Sourceval rotation_current : [< `V1 | `V2 ] t -> angle:int32 -> unit

Current rotation angle.

Current rotation angle.

Sourceval rotation_default : [< `V1 | `V2 ] t -> angle:int32 -> unit

Default rotation angle.

Default rotation angle.

Sourceval rotation_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for rotation.

Rotation is supported if the supported argument is non-zero.

Sourceval dwtp_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwtp_state.t -> unit

Current disable-while-trackpointing state.

Current disable-while-trackpointing state.

Sourceval dwtp_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwtp_state.t -> unit

Default disable-while-trackpointing state.

Default disable-while-trackpointing state.

Sourceval dwtp_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for disable-while-trackpointing.

Disable-while-trackpointing is supported if the supported argument is non-zero.

Sourceval dwt_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwt_state.t -> unit

Current disable-while-typing state.

Current disable-while-typing state.

Sourceval dwt_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Dwt_state.t -> unit

Default disable-while-typing state.

Default disable-while-typing state.

Sourceval dwt_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for disable-while-typing.

Disable-while-typing is supported if the supported argument is non-zero.

Sourceval scroll_button_lock_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Scroll_button_lock_state.t -> unit

Current scroll button lock state.

Current scroll button lock state. Supported if scroll_methods.on_button_down is supported.

Sourceval scroll_button_lock_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Scroll_button_lock_state.t -> unit

Default scroll button lock state.

Default scroll button lock state. Supported if scroll_methods.on_button_down is supported.

Sourceval scroll_button_current : [< `V1 | `V2 ] t -> button:int32 -> unit

Current scroll button.

Current scroll button. Supported if scroll_methods.on_button_down is supported.

Sourceval scroll_button_default : [< `V1 | `V2 ] t -> button:int32 -> unit

Default scroll button.

Default scroll button. Supported if scroll_methods.on_button_down is supported.

Sourceval scroll_method_current : [< `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Scroll_method.t -> unit

Current scroll method.

Current scroll method.

Sourceval scroll_method_default : [< `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Scroll_method.t -> unit

Default scroll method.

Default scroll method.

Sourceval scroll_method_support : [< `V1 | `V2 ] t -> methods:int32 -> unit

Supported scroll methods.

The scroll methods supported by the device.

Sourceval middle_emulation_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Middle_emulation_state.t -> unit

Current middle mouse button emulation state.

Current middle mouse button emulation.

Sourceval middle_emulation_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Middle_emulation_state.t -> unit

Default middle mouse button emulation.

Default middle mouse button emulation.

Sourceval middle_emulation_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for middle mouse button emulation.

Middle mouse button emulation is supported if the supported argument is non-zero.

Sourceval clickfinger_button_map_current : [< `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Clickfinger_button_map.t -> unit

Current clickfinger button map.

Current clickfinger button map. Supported if click_methods.clickfinger is supported.

Sourceval clickfinger_button_map_default : [< `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Clickfinger_button_map.t -> unit

Default clickfinger button map.

Default clickfinger button map. Supported if click_methods.clickfinger is supported.

Sourceval click_method_current : [< `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Click_method.t -> unit

Current click method.

Current click method.

Sourceval click_method_default : [< `V1 | `V2 ] t -> method_:Imports.River_libinput_device_v1.Click_method.t -> unit

Default click method.

Default click method.

Sourceval click_method_support : [< `V1 | `V2 ] t -> methods:int32 -> unit

Supported click methods.

The click methods supported by the device.

Sourceval left_handed_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Left_handed_state.t -> unit

Current left-handed mode state.

Current left-handed mode.

Sourceval left_handed_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Left_handed_state.t -> unit

Default left-handed mode.

Default left-handed mode.

Sourceval left_handed_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for left-handed mode.

Left-handed mode is supported if the supported argument is non-zero.

Sourceval natural_scroll_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Natural_scroll_state.t -> unit

Current natural scroll state.

Current natural scroll.

Sourceval natural_scroll_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Natural_scroll_state.t -> unit

Default natural scroll.

Default natural scroll.

Sourceval natural_scroll_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for natural scroll.

Natural scroll is supported if the supported argument is non-zero.

Sourceval accel_speed_current : [< `V1 | `V2 ] t -> speed:string -> unit

Current acceleration speed.

Current acceleration speed.

Sourceval accel_speed_default : [< `V1 | `V2 ] t -> speed:string -> unit

Default acceleration speed.

Default acceleration speed.

Sourceval accel_profile_current : [< `V1 | `V2 ] t -> profile:Imports.River_libinput_device_v1.Accel_profile.t -> unit

Current acceleration profile.

Current acceleration profile.

Sourceval accel_profile_default : [< `V1 | `V2 ] t -> profile:Imports.River_libinput_device_v1.Accel_profile.t -> unit

Default acceleration profile.

Default acceleration profile.

Sourceval accel_profiles_support : [< `V1 | `V2 ] t -> profiles:int32 -> unit

Supported acceleration profiles.

Supported acceleration profiles.

Sourceval calibration_matrix_current : [< `V1 | `V2 ] t -> matrix:string -> unit

Current calibration matrix.

Current calibration matrix.

Sourceval calibration_matrix_default : [< `V1 | `V2 ] t -> matrix:string -> unit

Default calibration matrix.

Default calibration matrix.

Sourceval calibration_matrix_support : [< `V1 | `V2 ] t -> supported:int32 -> unit

Support for a calibration matrix.

A calibration matrix is supported if the supported argument is non-zero.

Sourceval three_finger_drag_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Three_finger_drag_state.t -> unit

Current three finger drag state.

Current three finger drag state.

Sourceval three_finger_drag_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Three_finger_drag_state.t -> unit

Default three finger drag state.

Default three finger drag state.

Sourceval three_finger_drag_support : [< `V1 | `V2 ] t -> finger_count:int32 -> unit

Three finger drag support.

The number of fingers supported for three/four finger drag. If finger_count is less than 3, three finger drag is unsupported.

Sourceval drag_lock_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_lock_state.t -> unit

Current drag lock state.

Current drag lock state.

Sourceval drag_lock_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_lock_state.t -> unit

Default drag lock state.

Default drag lock state.

Sourceval drag_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_state.t -> unit

Current tap-and-drag state.

Current tap-and-drag state.

Sourceval drag_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Drag_state.t -> unit

Default tap-and-drag state.

Default tap-and-drag state.

Sourceval tap_button_map_current : [< `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Tap_button_map.t -> unit

Current tap-to-click button map.

Current tap-to-click button map.

Sourceval tap_button_map_default : [< `V1 | `V2 ] t -> button_map:Imports.River_libinput_device_v1.Tap_button_map.t -> unit

Default tap-to-click button map.

Default tap-to-click button map.

Sourceval tap_current : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Tap_state.t -> unit

Current tap-to-click state.

Current tap-to-click state.

Sourceval tap_default : [< `V1 | `V2 ] t -> state:Imports.River_libinput_device_v1.Tap_state.t -> unit

Default tap-to-click state.

Default tap-to-click state.

Sourceval tap_support : [< `V1 | `V2 ] t -> finger_count:int32 -> unit

Tap-to-click/drag support.

The number of fingers supported for tap-to-click/drag. If finger_count is 0, tap-to-click and drag are unsupported.

Sourceval send_events_current : [< `V1 | `V2 ] t -> mode:int32 -> unit

Current send events mode.

Current send events mode.

Sourceval send_events_default : [< `V1 | `V2 ] t -> mode:int32 -> unit

Default send events mode.

Default send events mode.

Sourceval send_events_support : [< `V1 | `V2 ] t -> modes:int32 -> unit

Supported send events modes.

Supported send events modes.

Sourceval input_device : [< `V1 | `V2 ] t -> device:([ `River_input_device_v1 ], 'a, [ `Server ]) Wayland.Proxy.t -> unit

Corresponding river input device.

The river_input_device_v1 corresponding to this libinput device. This event will always be the first event sent on the river_libinput_device_v1 object, and it will be sent exactly once.

Sourceval removed : [< `V1 | `V2 ] t -> unit

The libinput device is removed.

This event indicates that the libinput device has been removed.

The server will send no further events on this object and ignore any request (other than river_libinput_device_v1.destroy) made after this event is sent. The client should destroy this object with the river_libinput_device_v1.destroy request to free up resources.

Version 2

Sourceval done_ : [< `V2 ] t -> unit

All information has been sent.

This event is sent after all information about the libinput device has been sent.

This allows changes to one or more river_libinput_device_v1 properties to be seen as atomic, even if they happen via multiple events.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.