package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_libinput_result_v1Source

Config application result.

The result returned by libinput on setting configuration for a device.

Sourcetype 'v t = ([ `River_libinput_result_v1 ], 'v, [ `Server ]) Wayland.Proxy.t

Version 1

Sourceval invalid : [< `V1 ] t -> unit

Config invalid.

The configuration is invalid and was ignored.

Sourceval unsupported : [< `V1 ] t -> unit

Config unsupported.

The configuration is unsupported by the device and was ignored.

Sourceval success : [< `V1 ] t -> unit

Config success.

The configuration was successfully applied to the device.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.