package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_node_v1.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 | `V2 | `V3 | `V4 | `V5 ]
method private virtual on_destroy : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Destroy the decoration object.

This request indicates that the client will no longer use the node object and that it may be safely destroyed.

method private virtual on_set_position : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> x:int32 -> y:int32 -> unit

Set absolute position of the node.

Set the absolute position of the node in the compositor's logical coordinate space. The x and y coordinates may be positive or negative.

Note that the position of a river_window_v1 refers to the position of the window content and is unaffected by the presence of borders or decoration surfaces.

If this request is never sent, the position of the node is undefined by this protocol and left up to the compositor.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method private virtual on_place_top : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Place node above all other nodes.

This request places the node above all other nodes in the compositor's render list.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method private virtual on_place_bottom : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Place node below all other nodes.

This request places the node below all other nodes in the compositor's render list.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method private virtual on_place_above : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> other: ([ `River_node_v1 ], [> Imports.River_node_v1.versions ], [ `Server ]) Proxy.t -> unit

Place node above another node.

This request places the node directly above another node in the compositor's render list.

Attempting to place a node above itself has no effect.

Given nodes A, B, C currently rendered in that order with C on top and A on the bottom, the following example demonstrates the behavior of this request and the meaning of "directly above":

1. A.place_above(C) -> B, C, A 2. A.place_above(B) -> B, A, C 3. B.place_above(A) -> A, B, C

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method private virtual on_place_below : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> other: ([ `River_node_v1 ], [> Imports.River_node_v1.versions ], [ `Server ]) Proxy.t -> unit

Place node below another node.

This request places the node directly below another node in the compositor's render list.

Attempting to place a node below itself has no effect.

Given nodes A, B, C currently rendered in that order with C on top and A on the bottom, the following example demonstrates the behavior of this request and the meaning of "directly below":

1. C.place_below(A) -> C, A, B 2. C.place_below(B) -> A, C, B 3. B.place_below(C) -> A, B, C

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method min_version : int32