package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_output_v1.v3Source

Handler for a proxy with version >= 3.

constraint 'a = [< `V3 | `V4 | `V5 ]
method private virtual on_destroy : [> `V3 | `V4 | `V5 ] t -> unit

Destroy the output object.

This request indicates that the client will no longer use the output object and that it may be safely destroyed.

This request should be made after the river_output_v1.removed event is received to complete destruction of the output.

method private virtual on_set_presentation_mode : [> `V4 | `V5 ] t -> mode:Imports.River_output_v1.Presentation_mode.t -> unit

Set the preferred presentation mode.

Set the preferred presentation mode of the output. The compositor should always respect the preference of the window manager if possible. If this request is never made, the preferred presentation mode is vsync.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

method min_version : int32