package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module River_seat_v1.ModifiersSource

A set of keyboard modifiers.

This enum is used to describe the keyboard modifiers that must be held down to trigger a key binding or pointer binding.

Note that river and wlroots use the values 2 and 16 for capslock and numlock internally. It doesn't make sense to use locked modifiers for bindings however so these values are not included in this enum.

Sourcetype t = int32
Sourceval none : int32
Sourceval shift : int32
Sourceval ctrl : int32
Sourceval mod1 : int32
Sourceval mod3 : int32
Sourceval mod4 : int32
Sourceval mod5 : int32
Sourceval to_int32 : 'a -> 'a
Sourceval of_int32 : 'a -> 'a