package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Window_management.River_shell_surface_v1Source

A surface for window manager UI.

The window manager might use a shell surface to display a status bar, background image, desktop notifications, launcher, desktop menu, or whatever else it wants.

Sourcetype 'v t = ([ `River_shell_surface_v1 ], 'v, [ `Server ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1, 2, 3, 4, 5

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass virtual +'a v3 : object ... end

Handler for a proxy with version >= 3.

Sourceclass virtual +'a v4 : object ... end

Handler for a proxy with version >= 4.

Sourceclass virtual +'a v5 : object ... end

Handler for a proxy with version >= 5.