package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_xkb_keymap_v1Source

Xkbcommon keymap.

This object is the result of attempting to create an xkbcommon keymap.

Sourcetype 'v t = ([ `River_xkb_keymap_v1 ], 'v, [ `Server ]) Wayland.Proxy.t

Version 1, 2

Sourceval failure : [< `V1 | `V2 ] t -> error_msg:string -> unit

Keymap creation failed.

The compositor failed to create a keymap from the given parameters.

It is a protocol error to use this keymap object with river_xkb_keyboard_v1.set_keymap.

Sourceval success : [< `V1 | `V2 ] t -> unit

Keymap creation succeeded.

The keymap object was successfully created and may be used with the river_xkb_keyboard_v1.set_keymap request.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.