package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Window_management.River_output_v1Source

A logical output.

An area in the compositor's logical coordinate space that should be treated as a single output for window management purposes. This area may correspond to a single physical output or multiple physical outputs in the case of mirroring or tiled monitors depending on the hardware and compositor configuration.

Sourcetype 'v t = ([ `River_output_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end
Sourcemodule Presentation_mode : sig ... end

Version 1, 2, 3

Sourceval destroy : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Destroy the output object.

This request indicates that the client will no longer use the output object and that it may be safely destroyed.

This request should be made after the river_output_v1.removed event is received to complete destruction of the output.

Version 4

Sourceval set_presentation_mode : [< `V4 | `V5 ] t -> mode:Imports.River_output_v1.Presentation_mode.t -> unit

Set the preferred presentation mode.

Set the preferred presentation mode of the output. The compositor should always respect the preference of the window manager if possible. If this request is never made, the preferred presentation mode is vsync.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

Version 5

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass virtual +'a v3 : object ... end

Handler for a proxy with version >= 3.

Sourceclass virtual +'a v4 : object ... end

Handler for a proxy with version >= 4.

Sourceclass virtual +'a v5 : object ... end

Handler for a proxy with version >= 5.