package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module River_output_v1.Presentation_modeSource

Sourcetype t =
  1. | Vsync : t
    (*

    Tearing-free presentation.

    Output page-flips should be synchronized to the vertical blanking period, eliminating tearing. This is the default presentation mode.

    *)
  2. | Async : t
    (*

    Asynchronous presentation.

    Output page-flips should not be synchronized to the vertical blanking period, visual screen tearing may occur.

    *)
Sourceval to_int32 : t -> int32
Sourceval of_int32 : int32 -> t