package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_output_v1.v2Source

Handler for a proxy with version >= 2.

constraint 'a = [< `V2 | `V3 | `V4 | `V5 ]
method private virtual on_removed : [> `V2 | `V3 | `V4 | `V5 ] t -> unit

The output is removed.

This event indicates that the logical output is no longer conceptually part of window management space.

The server will send no further events on this object and ignore any request (other than river_output_v1.destroy) made after this event is sent. The client should destroy this object with the river_output_v1.destroy request to free up resources.

This event may be sent because a corresponding physical output has been physically unplugged or because some output configuration has changed.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method private virtual on_wl_output : [> `V2 | `V3 | `V4 | `V5 ] t -> name:int32 -> unit

Corresponding wl_output.

The wl_output object corresponding to the river_output_v1. The argument is the global name of the wl_output advertised with wl_registry.global.

It is guaranteed that the corresponding wl_output is advertised before this event is sent.

This event is sent exactly once. The wl_output associated with a river_output_v1 cannot change. It is guaranteed that there is a 1-to-1 mapping between wl_output and river_output_v1 objects.

The global_remove event for the corresponding wl_output may be sent before the river_output_v1.removed event. This is due to the fact that river_output_v1 state changes are synced to the river window management manage sequence while changes to globals are not.

Rationale: The window manager may need information provided by the wl_output interface such as the name/description. It also may need the wl_output object to start screencopy for example.

method private virtual on_position : [> `V2 | `V3 | `V4 | `V5 ] t -> x:int32 -> y:int32 -> unit

Output position.

This event indicates the position of the output in the compositor's logical coordinate space. The x and y coordinates may be positive or negative.

This event is sent once when the river_output_v1 is created and again whenever the position changes.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The server must guarantee that the position and dimensions events do not cause the areas of multiple logical outputs to overlap when the corresponding manage_start event is received.

method private virtual on_dimensions : [> `V2 | `V3 | `V4 | `V5 ] t -> width:int32 -> height:int32 -> unit

Output dimensions.

This event indicates the dimensions of the output in the compositor's logical coordinate space. The width and height will always be strictly greater than zero.

This event is sent once when the river_output_v1 is created and again whenever the dimensions change.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The server must guarantee that the position and dimensions events do not cause the areas of multiple logical outputs to overlap when the corresponding manage_start event is received.

method private virtual on_capture_sessions : [> `V5 ] t -> count:int32 -> unit

Output screen capture sessions.

This event informs the window manager of the number of active screen capture sessions for the output.

This event is sent once when the river_output_v1 is created and again whenever the number of capture sessions changes.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method min_version : int32