package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Window_management.River_pointer_binding_v1Source

Configure a pointer binding, receive trigger events.

This object allows the window manager to configure a pointer binding and receive events when the binding is triggered.

The new pointer binding is not enabled until the enable request is made during a manage sequence.

Normally, all pointer button events are sent to the surface with pointer focus by the compositor. Pointer button events that trigger a pointer binding are not sent to the surface with pointer focus.

If multiple pointer bindings would be triggered by a single physical pointer event on the compositor side, it is compositor policy which pointer binding(s) will receive press/release events or if all of the matched pointer bindings receive press/release events.

Sourcetype 'v t = ([ `River_pointer_binding_v1 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1, 2, 3, 4, 5

Sourceval disable : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Disable the pointer binding.

This request may be used to temporarily disable the pointer binding. It may be later re-enabled with the enable request.

This request modifies window management state and may only be made as part of a manage sequence, see the river_window_manager_v1 description.

Sourceval enable : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Enable the pointer binding.

This request should be made after all initial configuration has been completed and the window manager wishes the pointer binding to be able to be triggered.

This request modifies window management state and may only be made as part of a manage sequence, see the river_window_manager_v1 description.

Sourceval destroy : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Destroy the pointer binding object.

This request indicates that the client will no longer use the pointer binding object and that it may be safely destroyed.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass virtual +'a v3 : object ... end

Handler for a proxy with version >= 3.

Sourceclass virtual +'a v4 : object ... end

Handler for a proxy with version >= 4.

Sourceclass virtual +'a v5 : object ... end

Handler for a proxy with version >= 5.