package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_pointer_binding_v1.v4Source

Handler for a proxy with version >= 4.

constraint 'a = [< `V4 | `V5 ]
method private virtual on_pressed : [> `V4 | `V5 ] t -> unit

The bound pointer button has been pressed.

This event indicates that the pointer button triggering the binding has been pressed.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The compositor should wait for the manage sequence to complete before processing further input events. This allows the window manager client to, for example, modify key bindings and keyboard focus without racing against future input events. The window manager should of course respond as soon as possible as the capacity of the compositor to buffer incoming input events is finite.

method private virtual on_released : [> `V4 | `V5 ] t -> unit

The bound pointer button has been released.

This event indicates that the pointer button triggering the binding has been released.

Releasing the modifiers for the binding without releasing the pointer button does not trigger the release event. This event is sent when the pointer button is released, even if the modifiers have changed since the pressed event.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The compositor should wait for the manage sequence to complete before processing further input events. This allows the window manager client to, for example, modify key bindings and keyboard focus without racing against future input events. The window manager should of course respond as soon as possible as the capacity of the compositor to buffer incoming input events is finite.

method min_version : int32