package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Window_management.River_shell_surface_v1Source

A surface for window manager UI.

The window manager might use a shell surface to display a status bar, background image, desktop notifications, launcher, desktop menu, or whatever else it wants.

Sourcetype 'v t = ([ `River_shell_surface_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1, 2, 3, 4, 5

Sourceval sync_next_commit : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Sync next surface commit to window manager commit.

Synchronize application of the next wl_surface.commit request on the shell surface with rest of the rendering state atomically applied with the next river_window_manager_v1.render_finish request.

The client must make a wl_surface.commit request on the shell surface after this request and before the render_finish request, failure to do so is a protocol error.

This request modifies rendering state and may only be made as part of a render sequence, see the river_window_manager_v1 description.

Sourceval get_node : ([< `V1 | `V2 | `V3 | `V4 | `V5 ] as 'a) t -> [[ `River_node_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> ([ `River_node_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Get the shell surface's render list node.

Get the node in the render list corresponding to the shell surface.

It is a protocol error to make this request more than once for a single shell surface.

Sourceval destroy : [< `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Destroy the shell surface object.

This request indicates that the client will no longer use the shell surface object and that it may be safely destroyed.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass +'a v3 : object ... end

Handler for a proxy with version >= 3.

Sourceclass +'a v4 : object ... end

Handler for a proxy with version >= 4.

Sourceclass +'a v5 : object ... end

Handler for a proxy with version >= 5.