package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_window_manager_v1.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 | `V2 | `V3 | `V4 | `V5 ]
method private virtual on_unavailable : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Window management unavailable.

This event indicates that window management is not available to the client, perhaps due to another window management client already running. The circumstances causing this event to be sent are compositor policy.

If sent, this event is guaranteed to be the first and only event sent by the server.

The server will send no further events on this object. The client should destroy this object and all objects created through this interface.

method private virtual on_finished : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

The server has finished with the window manager.

This event indicates that the server will send no further events on this object. The client should destroy the object. See river_window_manager_v1.destroy for more information.

method private virtual on_manage_start : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Start a manage sequence.

This event indicates that the server has sent events indicating all state changes since the last manage sequence.

In response to this event, the client should make requests modifying window management state as it chooses. Then, the client must make the manage_finish request.

See the description of the river_window_manager_v1 interface for a complete overview of the manage/render sequence loop.

method private virtual on_render_start : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

Start a render sequence.

This event indicates that the server has sent all river_window_v1.dimensions events necessary.

In response to this event, the client should make requests modifying rendering state as it chooses. Then, the client must make the render_finish request.

See the description of the river_window_manager_v1 interface for a complete overview of the manage/render sequence loop.

method private virtual on_session_locked : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

The session has been locked.

This event indicates that the session has been locked.

The window manager may wish to restrict which key bindings are available while locked or otherwise use this information.

If the session is currently locked when the river_window_manager_v1 object is created, the session_locked event will be sent in the first manage sequence.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method private virtual on_session_unlocked : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> unit

The session has been unlocked.

This event indicates that the session has been unlocked.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method private virtual on_window : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> ([ `River_window_v1 ], 'a, [ `Client ]) Proxy.t -> unit

New window.

A new window has been created.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method private virtual on_output : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> ([ `River_output_v1 ], 'a, [ `Client ]) Proxy.t -> unit

New output.

A new logical output has been created, perhaps due to a new physical monitor being plugged in or perhaps due to a change in configuration.

This event will be followed by river_output_v1.position and dimensions events as well as a manage_start event after all other new state has been sent by the server.

method private virtual on_seat : [> `V1 | `V2 | `V3 | `V4 | `V5 ] t -> ([ `River_seat_v1 ], 'a, [ `Client ]) Proxy.t -> unit

New seat.

A new seat has been created.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method min_version : int32
method bind_version : [ `V1 ]