package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_xkb_binding_v1.v2Source

Handler for a proxy with version >= 2.

constraint 'a = [< `V2 | `V3 ]
method private virtual on_pressed : [> `V2 | `V3 ] t -> unit

The key triggering the binding has been pressed.

This event indicates that the physical key triggering the binding has been pressed.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The compositor should wait for the manage sequence to complete before processing further input events. This allows the window manager client to, for example, modify key bindings and keyboard focus without racing against future input events. The window manager should of course respond as soon as possible as the capacity of the compositor to buffer incoming input events is finite.

method private virtual on_released : [> `V2 | `V3 ] t -> unit

The key triggering the binding has been released.

This event indicates that the physical key triggering the binding has been released.

Releasing the modifiers for the binding without releasing the "main" physical key that produces the bound keysym does not trigger the release event. This event is sent when the "main" key is released, even if the modifiers have changed since the pressed event.

This event will be followed by a manage_start event after all other new state has been sent by the server.

The compositor should wait for the manage sequence to complete before processing further input events. This allows the window manager client to, for example, modify key bindings and keyboard focus without racing against future input events. The window manager should of course respond as soon as possible as the capacity of the compositor to buffer incoming input events is finite.

method private virtual on_stop_repeat : [> `V2 | `V3 ] t -> unit

Repeating should be stopped.

This event indicates that repeating should be stopped for the binding if the window manager has been repeating some action since the pressed event.

This event is generally sent when some other (possibly unbound) key is pressed after the pressed event is sent and before the released event is sent for this binding.

This event will be followed by a manage_start event after all other new state has been sent by the server.

method min_version : int32