package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Bindings.River_xkb_bindings_v1Source

Xkbcommon bindings global interface.

This global interface should only be advertised to the client if the river_window_manager_v1 global is also advertised.

Sourcetype 'v t = ([ `River_xkb_bindings_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1

Sourceval get_xkb_binding : ([< `V1 | `V2 | `V3 ] as 'a) t -> seat:([ `River_seat_v1 ], 'b, [ `Client ]) Wayland.Proxy.t -> [[ `River_xkb_binding_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> keysym:int32 -> modifiers:int32 -> ([ `River_xkb_binding_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Define a new xkbcommon key binding.

Define a key binding for the given seat in terms of an xkbcommon keysym and other configurable properties.

The new key binding is not enabled until initial configuration is completed and the enable request is made during a manage sequence.

Sourceval destroy : [< `V1 | `V2 | `V3 ] t -> unit

Destroy the river_xkb_bindings_v1 object.

This request indicates that the client will no longer use the river_xkb_bindings_v1 object.

Version 2, 3

Sourceval get_seat : ([< `V2 | `V3 ] as 'a) t -> [[ `River_xkb_bindings_seat_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> seat:([ `River_seat_v1 ], 'b, [ `Client ]) Wayland.Proxy.t -> ([ `River_xkb_bindings_seat_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Manage seat-specific state.

Create an object to manage seat-specific xkb bindings state.

It is a protocol error to make this request more than once for a given river_seat_v1 object.

Handlers

Note: Servers will always want to use v1.

Sourceclass +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass +'a v2 : object ... end

Handler for a proxy with version >= 2.

Sourceclass +'a v3 : object ... end

Handler for a proxy with version >= 3.