package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_xkb_config_v1Source

Xkb config global interface.

Global interface for configuring xkb devices.

This global should only be advertised if river_input_manager_v1 is advertised as well.

Sourcetype 'v t = ([ `River_xkb_config_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end
Sourcemodule Keymap_format : sig ... end

Version 1, 2

Sourceval create_keymap : ([< `V1 | `V2 ] as 'a) t -> [[ `River_xkb_keymap_v1 ], 'a, [ `Client ]] Wayland.Proxy.Handler.t -> fd:Unix.file_descr -> format:Imports.River_xkb_config_v1.Keymap_format.t -> ([ `River_xkb_keymap_v1 ], 'a, [ `Client ]) Wayland.Proxy.t

Create a keymap object.

The server must be able to mmap the fd with MAP_PRIVATE. The server will fstat the fd to obtain the size of the keymap. The client must not modify the contents of the fd after making this request. The client should seal the fd with fcntl.

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the river_xkb_config_v1 object.

This request should be called after the finished event has been received to complete destruction of the object.

It is a protocol error to make this request before the finished event has been received.

If a client wishes to destroy this object it should send a river_xkb_config_v1.stop request and wait for a river_xkb_config_v1.finished event. Once the finished event is received it is safe to destroy this object and any other objects created through this interface.

Sourceval stop : [< `V1 | `V2 ] t -> unit

Stop sending events.

This request indicates that the client no longer wishes to receive events on this object.

The Wayland protocol is asynchronous, which means the server may send further events until the stop request is processed. The client must wait for a river_xkb_config_v1.finished event before destroying this object.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.