package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_xkb_keyboard_v1Source

Xkbcommon keyboard device.

This object represent a physical keyboard which has its configuration and state managed by xkbcommon.

Sourcetype 'v t = ([ `River_xkb_keyboard_v1 ], 'v, [ `Client ]) Wayland.Proxy.t
Sourcemodule Error : sig ... end

Version 1

Sourceval numlock_disable : [< `V1 | `V2 ] t -> unit

Disable numlock.

Disable numlock for the keyboard.

Sourceval numlock_enable : [< `V1 | `V2 ] t -> unit

Enable numlock.

Enable numlock for the keyboard.

Sourceval capslock_disable : [< `V1 | `V2 ] t -> unit

Disable capslock.

Disable capslock for the keyboard.

Sourceval capslock_enable : [< `V1 | `V2 ] t -> unit

Enable capslock.

Enable capslock for the keyboard.

Sourceval set_layout_by_name : [< `V1 | `V2 ] t -> name:string -> unit

Set the active layout by name.

Set the active layout for the keyboard's keymap. Has no effect if there is no layout with the give name for the keyboard's keymap.

Sourceval set_layout_by_index : [< `V1 | `V2 ] t -> index:int32 -> unit

Set the active layout by index.

Set the active layout for the keyboard's keymap. Has no effect if the layout index is out of bounds for the current keymap.

Sourceval set_keymap : [< `V1 | `V2 ] t -> keymap:([ `River_xkb_keymap_v1 ], 'a, [ `Client ]) Wayland.Proxy.t -> unit

Set the keymap.

Set the keymap for the keyboard.

Setting a keymap will reset all layout/modifier state.

It is a protocol error to pass a keymap object for which the river_xkb_keymap_v1.success event was not received.

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the xkb keyboard object.

This request indicates that the client will no longer use the keyboard object and that it may be safely destroyed.

Version 2

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.