package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_xkb_keyboard_v1.v1Source

Handler for a proxy with version >= 1.

constraint 'a = [< `V1 | `V2 ]
method private virtual on_removed : [> `V1 | `V2 ] t -> unit

The xkb keyboard is removed.

This event indicates that the xkb keyboard has been removed.

The server will send no further events on this object and ignore any request (other than river_xkb_keyboard_v1.destroy) made after this event is sent. The client should destroy this object with the river_xkb_keyboard_v1.destroy request to free up resources.

method private virtual on_input_device : [> `V1 | `V2 ] t -> device: ([ `River_input_device_v1 ], [> Imports.River_input_device_v1.versions ], [ `Client ]) Proxy.t -> unit

Corresponding river input device.

The river_input_device_v1 corresponding to this xkb keyboard. This event will always be the first event sent on the river_xkb_keyboard_v1 object, and it will be sent exactly once.

method private virtual on_layout : [> `V1 | `V2 ] t -> index:int32 -> name:string option -> unit

Currently active layout.

The currently active layout index and name. The name arg may be null if the active layout does not have a name.

This event is sent once when the river_xkb_keyboard_v1 is created and again whenever the layout changes.

method private virtual on_capslock_enabled : [> `V1 | `V2 ] t -> unit

Capslock is currently enabled.

Capslock is currently enabled for the keyboard.

This event is sent once when the river_xkb_keyboard_v1 is created and again whenever the capslock state changes.

method private virtual on_capslock_disabled : [> `V1 | `V2 ] t -> unit

Capslock is currently disabled.

Capslock is currently disabled for the keyboard.

This event is sent once when the river_xkb_keyboard_v1 is created and again whenever the capslock state changes.

method private virtual on_numlock_enabled : [> `V1 | `V2 ] t -> unit

Numlock is currently enabled.

Numlock is currently enabled for the keyboard.

This event is sent once when the river_xkb_keyboard_v1 is created and again whenever the numlock state changes.

method private virtual on_numlock_disabled : [> `V1 | `V2 ] t -> unit

Numlock is currently disabled.

Numlock is currently disabled for the keyboard.

This event is sent once when the river_xkb_keyboard_v1 is created and again whenever the numlock state changes.

method private virtual on_done : [> `V2 ] t -> unit

All information has been sent.

This event is sent after all information about the keyboard has been sent.

This allows changes to one or more river_xkb_keyboard_v1 properties to be seen as atomic, even if they happen via multiple events.

method min_version : int32