package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Config.River_xkb_keymap_v1Source

Xkbcommon keymap.

This object is the result of attempting to create an xkbcommon keymap.

Sourcetype 'v t = ([ `River_xkb_keymap_v1 ], 'v, [ `Client ]) Wayland.Proxy.t

Version 1, 2

Sourceval destroy : [< `V1 | `V2 ] t -> unit

Destroy the keymap object.

This request indicates that the client will no longer use the keymap object and that it may be safely destroyed.

Handlers

Note: Servers will always want to use v1.

Sourceclass virtual +'a v1 : object ... end

Handler for a proxy with version >= 1.

Sourceclass virtual +'a v2 : object ... end

Handler for a proxy with version >= 2.