package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Class River_xkb_keymap_v1.v2Source

Handler for a proxy with version >= 2.

constraint 'a = [< `V2 ]
method private virtual on_success : [> `V2 ] t -> unit

Keymap creation succeeded.

The keymap object was successfully created and may be used with the river_xkb_keyboard_v1.set_keymap request.

method private virtual on_failure : [> `V2 ] t -> error_msg:string -> unit

Keymap creation failed.

The compositor failed to create a keymap from the given parameters.

It is a protocol error to use this keymap object with river_xkb_keyboard_v1.set_keymap.

method min_version : int32