package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_runtime.EventsSource

seed wm sub fills sub's pending buffer with the last-published snapshots matching its filters and wakes its drain fiber.

Effects: mutates WM state

Sourceval publish : Oxbow_state.Wm.t -> unit

publish wm diffs current snapshots against the last-published set, updates matching subscribers with the changes, and records the new set.

Effects: mutates WM state