package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_runtime.LifecycleSource

Sourceval request_exit : ?origin:[ `Local | `Compositor ] -> Oxbow_state.Wm.t -> unit

request_exit ?origin wm indicates a request to end the session made by the user, a process signal, or River itself. No-op when wm is not Running.

Effects: mutates WM state

Sourceval request_close : Oxbow_state.Wm.t -> unit

request_close wm is a request to close oxbow but not River. No-op when wm is not Running.

Effects: mutates WM state

Sourceval dispatch_pending : Oxbow_state.Wm.t -> unit

dispatch_pending wm handles the pending exit/close state for wm.

Effects: mutates WM state

Sourceval notify_finished : Oxbow_state.Wm.t -> unit

notify_finished wm broadcast oxbow is closing.

Effects: mutates WM state

Sourceval await_shutdown : Oxbow_state.Wm.t -> unit

await_shutdown wm blocks the current fiber until request_shutdown has been called. No-op if shutdown is already in progress.

Effects: mutates WM state

Sourceval teardown : clock:[> float Eio.Time.clock_ty ] Eio.Resource.t -> Oxbow_state.Wm.t -> unit

teardown ~clock wm handles wm cleanup.

Effects: mutates WM state