package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_state.OutputSource

include module type of Types.Output
Sourcemodule Lifecycle : sig ... end
Sourcemodule Tags : sig ... end
Sourcemodule Overview : sig ... end
type t = {
  1. obj : Wire.Obj.Window_management.Output.t;
  2. layer_shell : Wire.Obj.Layer_shell.Output.t;
  3. mutable lifecycle : Lifecycle.t;
  4. mutable is_captured : bool;
  5. mutable name : string option;
  6. mutable labels : string list;
  7. mutable geom : int32 Oxbow_core.Rect.t;
  8. mutable usable : int Oxbow_core.Rect.t;
  9. tags : Tags.t;
  10. overview : Overview.t;
  11. tag_data : Types.Config.Data.t Oxbow_core.Tag.Table.t;
  12. mutable focus_stack : Types.Window.t list;
  13. mutable wm_stack : Types.Window.t list;
}
Sourceval focused_window : t -> Types.Window.t option

focused_window output is Some window when output has a focused visible window

Sourceval next_window : t -> Types.Window.t option

next_window output is the window after the currently focused window in output's window stack. This may be equal to focused_window if it is the only window in the stack or None if there are no windows in the stack. Wraps at stack edges

Sourceval prev_window : t -> Types.Window.t option

prev_window output is the window before the currently focused window in output's window stack. This may be equal to focused_window if it is the only window in the stack or None if there are no windows in the stack. Wraps at stack edges.

tag_data output tags is the tag data of output the first set tag of tags. Raises Invalid_argument if tags is the empty set.

Sourceval to_tag_data : t -> Config.Data.t

to_tag_data output is the tag data of the first selected tag of output. Raises Invalid_argument if output has no selected tags.

Sourceval at_point : x:int32 -> y:int32 -> t list -> t option

at_point ~x ~y lst returns the first output that contains point (x, y). Is None when the point is out of bounds.

Sourceval switch_tags : tags:Oxbow_core.Tag.Set.t -> t -> unit

switch_tags ~tags output changes the selected tags of output to tags. No-op if Tag.Set.is_empty tags is true.

Effects: mutates WM state

Sourceval occupied_tags : t -> Oxbow_core.Tag.Set.t

occupied_tags output is the tag set containing all tags with active windows.

Sourceval urgent_tags : t -> Oxbow_core.Tag.Set.t

occupied_tags output is the tag set containing all tags with urgent windows.

Sourceval current_layout : t -> Oxbow_core.Layout.t

current_layout output is the layout of the first selected tag of output.

Sourceval current_scheme : t -> Oxbow_core.Scheme.t

current_scheme output is the scheme of the first selected tag of output.

Sourceval windows_on_tags : t -> tags:Oxbow_core.Tag.Set.t -> Types.Window.t list

windows_on_tags output ~tags is the list of output's windows on tags.

Sourceval visible_windows : t -> Types.Window.t list

visible_windows output is the list of visible windows on the selected tags of output.

Sourceval visible_window_count : t -> int

visible_window_count output is the length of visible_windows o.

Sourceval tiled_windows : t -> Types.Window.t list

tiled_windows output is the list of tiled windows on the selected tags of output.

Sourceval has_visible_fullscreen : t -> bool

has_visible_fullscreen output is true when a window is fullscreen and tag visible on output.

Sourceval is_floating : t option -> bool

is_floating output is true when output is in the Floating layout.

Sourceval apply_layout : Types.Config.Data.t -> layout:Oxbow_core.Layout.t -> unit

apply_layout td ~layout applies layout to the layout of td.

Effects: mutates WM state

Sourceval apply_scheme : Types.Config.Data.t -> scheme:Oxbow_core.Scheme.t -> unit

apply_scheme td ~scheme applies scheme to the scheme of td.

Effects: mutates WM state

Sourceval enter_overview : t -> unit

enter_overview output activates overview mode for output if not already active.

Effects: mutates WM state

Sourceval exit_overview : t -> unit

exit_overview output deactivates overview mode for output if active.

Effects: mutates WM state

Sourceval apply_mfact : Types.Config.Data.t -> delta:float Oxbow_core.Delta.t -> unit

apply_mfact td ~delta applies delta to the mfact of td.

Effects: mutates WM state

Sourceval apply_nmaster : Types.Config.Data.t -> delta:int Oxbow_core.Delta.t -> unit

apply_nmaster td ~delta applies delta to the nmaster of td

Effects: mutates WM state

Sourceval apply_gaps_inner : Types.Config.Data.t -> delta:int Oxbow_core.Delta.t -> unit

apply_gaps_inner td ~delta applies delta to the inner gaps of td.

Effects: mutates WM state

Sourceval apply_gaps_outer : Types.Config.Data.t -> delta:int Oxbow_core.Delta.t -> unit

apply_gaps_outer td ~delta applies delta to the outer gaps of td.

Effects: mutates WM state

Sourceval apply_scrolling_align : Types.Config.Data.t -> align:Oxbow_core.Align.t -> unit

apply_scrolling_align td ~align applies align to the scroll layout of td.

Effects: mutates WM state

Sourceval apply_scrolling_orientation : Types.Config.Data.t -> dir:Oxbow_core.Direction.Spatial.t -> unit

apply_scrolling_orientation td ~dir applies dir to the tiling orientation of td.

Effects: mutates WM state

Sourceval apply_tiling_orientation : Types.Config.Data.t -> dir:Oxbow_core.Direction.Spatial.t -> unit

apply_tiling_orientation td ~dir applies dir to the tiling orientation of td.

Effects: mutates WM state

Sourceval set_gaps_overview : t -> delta:int Oxbow_core.Delta.t -> unit

set_gaps_overview output ~delta sets the overview gaps for output according to delta.

Effects: mutates WM state

Sourceval set_overview_head : t -> Types.Window.t option -> unit

set_overview_head output head sets head as the first window of overview mode for output.

Effects: mutates WM state

Sourceval set_wm_stack : t -> Types.Window.t list -> unit

set_wm_stack output ws replaces output's window stack with ws.

Effects: mutates WM state

Sourceval set_focus_stack : t -> Types.Window.t list -> unit

set_focus_stack output ws replaces output's focus stack with ws.

Effects: mutates WM state

Sourceval resolve_tag_arg : arg:Oxbow_core.Tag.Arg.t -> t -> Oxbow_core.Tag.Set.t

resolve_tag_arg ~arg output returns the set of tags according to arg.

Sourceval to_vector : t -> Oxbow_core.Vector.t

to_vector output is the vector of output.

Sourceval matches_name : string -> t -> bool

matches_name output name is true iff output's name is exactly name.

Sourceval resolve_output_logical : dir:Oxbow_core.Direction.Logical.t -> t -> t list -> t option

resolve_output_logical ~dir current outputs is Some output in the logical direction dir from current or None if outputs is empty. Is Some current when current is the only output in outputs.

Sourceval resolve_output_spatial : from:Oxbow_core.Vector.t -> dir:Oxbow_core.Direction.Spatial.t -> t -> t list -> t option

resolve_output_spatial ~from ~dir current outputs is Some output in the spatial direction dir from current or None if no output qualifies.

Sourceval resolve_output_name : string -> t list -> t option

resolve_output_name name outputs is the first output in outputs where matches_name ~name output is true.

Sourceval set_lifecycle : t -> Lifecycle.t -> unit

set_lifecycle output lifecycle sets output's lifecycle to lifecycle.

Effects: mutates WM state

Sourceval set_is_captured : t -> bool -> unit

set_is_captured output is_captured sets output's captured status to is_captured.

Effects: mutates WM state

Sourceval set_usable : t -> int Oxbow_core.Rect.t -> unit

set_usable output usable sets output's usable geometry to usable.

Effects: mutates WM state

Sourceval set_name : t -> string option -> unit

set_name output name sets output's name to name.

Effects: mutates WM state

Sourceval add_label : t -> string -> unit

add_label output label adds label to output's label set. No-op when the label is present.

Effects: mutates WM state

Sourceval remove_label : t -> string -> unit

remove_label output label removes label from output's label set. No-op when label is absent.

Effects: mutates WM state

Sourceval set_geom : t -> int32 Oxbow_core.Rect.t -> unit

set_geom output geom sets output's geometry to geom.

Effects: mutates WM state

Sourceval set_scroll_offset : t -> int -> unit

set_scroll_offset output offset sets the scroll offset of the first active tag on output.

Effects: mutates WM state

Sourceval apply_default_width : Types.Config.Data.t -> delta:float Oxbow_core.Delta.t -> unit

apply_default_width td ~delta applies delta to the default width of td.

Effects: mutates WM state

Sourceval apply_float_seed : Types.Config.Data.t -> seed:Oxbow_core.Extent.t -> unit

apply_float_seed td ~seed sets the float seed of td to seed.

Effects: mutates WM state

Sourceval arranges : Types.Window.t -> bool

arranges window is true when window's output owns its dimensions and a proposal exists to defend.