package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_state.WithSource

Sourceval focused_output : Types.Seat.t -> (Types.Output.t -> ('a, string) result) -> ('a, string) result

focused_output seat f applies f to seat's focused output. Is Error msg if seat has no output.

Sourceval focused_output_log : ?out:[< `Debug | `Info | `Error | `Warn ] -> Types.Seat.t -> (Types.Output.t -> unit) -> unit

focused_output_log ?out seat f applies f to seat's focused output. Logs any Error msg according to out if seat has no output. If out is not present, Error msg will be logged to `Debug.

Sourceval named_output : name:string -> Types.Wm.t -> (Types.Output.t -> ('a, string) result) -> ('a, string) result

named_output ~name wm f applies f to the first output matching name. Is Error msg if wm contains no output matching name.

Sourceval named_output_log : ?out:[ `Debug | `Info | `Error | `Warn ] -> name:string -> Types.Wm.t -> (Types.Output.t -> unit) -> unit

named_output_log ?out ~name wm f applies f to the first output matching name. Logs any Error msg according to out if wm contains no output matching name. If out is not present, Error msg will be logged to `Debug.

Sourceval focused_window : Types.Seat.t -> (Types.Output.t -> Types.Window.t -> ('a, string) result) -> ('a, string) result

focused_window seat f applies f to seat's focused output and window. Is Error msg if seat has no output or focused window.

Sourceval focused_window_log : ?out:[< `Debug | `Info | `Error | `Warn ] -> Types.Seat.t -> (Types.Output.t -> Types.Window.t -> unit) -> unit

focused_window_log ?out seat f applies f to seat's focused output and window.Logs any Error msg according to out if seat has no output or window. If out is not present, Error msg will be logged to `Debug.

Sourceval output : Types.Window.t -> (Types.Output.t -> ('a, string) result) -> ('a, string) result

output window f applies f to window's outupt. Is Error msg if window has no output.

Sourceval output_log : ?out:[< `Debug | `Info | `Error | `Warn ] -> Types.Window.t -> (Types.Output.t -> unit) -> unit

output_log ?out window f applies f to window's output. Logs any Error msg according to out if window has no output. If out is not present, Error msg will be logged to `Debug.