package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Oxbow_state.WmSource

include module type of Types.Wm
Sourcemodule Lifecycle : sig ... end
Sourcemodule Ipc : sig ... end
type t = {
  1. river_wm_v1 : Wire.Obj.Window_management.t;
  2. river_xkb_v1 : Wire.Obj.Xkb.Bindings.t;
  3. river_lsh_v1 : Wire.Obj.Layer_shell.t;
  4. river_input_v1 : Wire.Obj.Input.Management.t;
  5. river_libinput_v1 : Wire.Obj.Input.Config.t;
  6. river_xkb_config_v1 : Wire.Obj.Xkb.Config.t;
  7. shutdown : Eio.Condition.t;
  8. mutable lifecycle : Lifecycle.t;
  9. mutable session_locked : bool;
  10. mutable primary_seat : Types.Seat.t option;
  11. mutable outputs : Types.Output.t list;
  12. mutable windows : Types.Window.t list;
  13. mutable seats : Types.Seat.t list;
  14. mutable input_devices : Types.Input_device.t list;
  15. mutable xkb_stash : (int32 * Wire.Obj.Xkb.Config.Keyboard.t) list;
  16. mutable keymap : Wire.Obj.Xkb.Config.Keymap.t option;
  17. mutable desired_keymap_path : string option;
  18. config : Types.Config.t;
  19. init_command : string option;
  20. mutable init_handle : Init_script.t option;
  21. ipc : Ipc.t;
}
Sourceval focused_output : t -> Types.Output.t option

focused_output wm is the focused output on wm's primary seat, or None if no primary seat is defined or no focused output is defined for the seat.

Sourceval default_output : t -> Types.Output.t option

default_output wm is wm's default output. Is None when wm has no outputs.

Sourceval ensure_seat_output : t -> Types.Seat.t -> unit

ensure_seat_output wm seat assigns default_output wm to seat if it has no current output. No-op if seat already has an output, or if no outputs exist.

Effects: mutates WM state

Sourceval set_primary_seat : t -> Types.Seat.t option -> unit

set_primary_seat wm primary_seat sets wm's primary seat to primary_seat.

Effects: mutates WM state

Sourceval set_outputs : t -> Types.Output.t list -> unit

set_outputs wm outputs sets wm's output list to outputs.

Effects: mutates WM state

Sourceval set_windows : t -> Types.Window.t list -> unit

set_windows wm windows sets wm's window list to windows.

Effects: mutates WM state

Sourceval set_seats : t -> Types.Seat.t list -> unit

set_seats wm seats sets wm's seat list to seats.

Effects: mutates WM state

Sourceval set_lifecycle : t -> Lifecycle.t -> unit

set_lifecycle wm lifecycle sets wm's lifecycle to lifecycle.

Effects: mutates WM state

Sourceval set_keymap : t -> Wire.Obj.Xkb.Config.Keymap.t option -> unit

set_keymap wm keymap sets wm's keymap to keymap.

Effects: mutates WM state

Sourceval set_desired_keymap_path : t -> string option -> unit

set_desired_keymap_path wm desired_keymap_path sets wm's keymap path to desired_keymap_path.

Effects: mutates WM state

Sourceval set_init_handle : t -> Init_script.t option -> unit

set_init_handle wm init_handle sets wm's init hanled to init_handle.

Effects: mutates WM state

Sourceval set_input_devices : t -> Types.Input_device.t list -> unit

set_input_devices wm input_devices sets wm's input device list to input_devices.

Effects: mutates WM state

Sourceval add_xkb_stash : t -> int32 -> Wire.Obj.Xkb.Config.Keyboard.t -> unit

add_xkb_stash wm device xkb adds (device, xkb) to wm's pending xkb list.

Effects: mutates WM state

Sourceval remove_xkb_stash : t -> int32 -> unit

remove_xkb_stash wm device removes all pending xkb entries matching device.

Effects: mutates WM state

Sourceval find_xkb_stash_opt : t -> int32 -> Wire.Obj.Xkb.Config.Keyboard.t option

find_xkb_stash_opt wm device is the pending xkb object matching device or None.

Sourceval add_input_device : t -> Types.Input_device.t -> unit

add_input_device wm device adds device to wm's input device list.

Effects: mutates WM state

Sourceval remove_input_device : t -> Types.Input_device.t -> unit

remove_input_device wm device removes device from wm's input device list.

Effects: mutates WM state

Sourceval find_input_device_opt : t -> int32 -> Types.Input_device.t option

find_input_device_opt wm id is the input device matching id. Is None when no input device matches.

Sourceval add_subscriber : t -> Ipc.Subscriber.t -> unit

add_subscriber wm sub registers sub to receive published events.

Effects: mutates WM state

Sourceval remove_subscriber : t -> Ipc.Subscriber.t -> unit

remove_subscriber wm sub removes sub from the subscriber registry; no-op when sub is not registered.

Effects: mutates WM state

Sourceval set_session_locked : t -> bool -> unit

set_session_locked wm locked records whether the session is locked.

Effects: mutates WM state