package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module EmitSource

Sourceval manage_dirty : Wire.Obj.Window_management.t -> unit

manage_dirty wm asks river for a manage sequence.

Sourceval exit_session : Wire.Obj.Window_management.t -> unit

exit_session wm asks river to end the session.

Sourceval set_xcursor_theme : Wire.Obj.Window_management.Seat.t -> name:string -> size:int32 -> unit

set_xcursor_theme seat ~name ~size sets the cursor theme of seat.

Sourceval set_default : Wire.Obj.Layer_shell.Output.t -> unit

set_default output makes output the default for layer surfaces.

Sourceval set_repeat_info : Wire.Obj.Input.Management.Device.t -> rate:int32 -> delay:int32 -> unit

set_repeat_info device ~rate ~delay sets the key repeat of device.

get_node window get window's render list node.

Sourceval create_xkb_binding : Wire.Obj.Xkb.Bindings.t -> seat:Wire.Obj.Window_management.Seat.t -> keysym:int32 -> mods:int32 -> on_pressed:(unit -> unit) -> Wire.Obj.Xkb.Bindings.Binding.t

create_xkb_binding xkb ~seat ~keysym ~mods ~on_pressed defines a new xkbcommon key binding.

Sourceval create_pointer_binding : Wire.Obj.Window_management.Seat.t -> button:int32 -> mods:int32 -> on_pressed:(unit -> unit) -> Wire.Obj.Window_management.Pointer_binding.t

create_pointer_binding seat ~button ~mods ~on_pressed defines a new pointer binding.

Sourceval create_xkb_bindings_seat : Wire.Obj.Xkb.Bindings.t -> seat:Wire.Obj.Window_management.Seat.t -> on_modifiers_update:(old:int32 -> new_:int32 -> unit) -> Wire.Obj.Xkb.Bindings.Seat.t

create_xkb_bindings_seat xkb ~seat ~on_modifiers_update creates the xkb bindings seat object for seat.

destroy_window ~window ~node destroys the window and node objects.

Sourceval destroy_output : output:Wire.Obj.Window_management.Output.t -> layer_shell:Wire.Obj.Layer_shell.Output.t -> unit

destroy_output ~output ~layer_shell destroys the output and layer_shell objects.

Sourceval destroy_xkb_binding : Wire.Obj.Xkb.Bindings.Binding.t -> unit

destroy_xkb_binding binding destroys the binding object.

Sourceval destroy_pointer_binding : Wire.Obj.Window_management.Pointer_binding.t -> unit

destroy_pointer_binding binding destroys the binding object.

destroy_seat ~seat ~layer_shell ~xkb_seat destroys the seat, layer_shell, and xkb_seat objects.

set_keymap keyboard ~keymap sets the keymap for keyboard.

Sourceval destroy_xkb_keyboard : Wire.Obj.Xkb.Config.Keyboard.t -> unit

destroy_xkb_keyboard keyboard destroys the keyboard object.

Sourceval destroy_input_device : Wire.Obj.Input.Management.Device.t -> unit

destroy_input_device device destroys the device object.

Sourceval set_tap : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_tap dev ~device enabled sets tap-to-click.

Sourceval set_drag : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_drag dev ~device enabled sets tap-and-drag.

Sourceval set_drag_lock : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Drag_lock_state.t -> unit

set_drag_lock dev ~device state sets the drag-lock mode.

Sourceval set_three_finger_drag : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Three_finger_drag_state.t -> unit

set_three_finger_drag dev ~device state sets the three-finger-drag mode.

Sourceval set_dwt : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_dwt dev ~device enabled sets disable-while-typing.

Sourceval set_dwtp : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_dwtp dev ~device enabled sets disable-while-trackpointing.

Sourceval set_natural_scroll : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_natural_scroll dev ~device enabled sets natural scroll.

Sourceval set_left_handed : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_left_handed dev ~device enabled sets left-handed mode.

Sourceval set_middle_emulation : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_middle_emulation dev ~device enabled sets middle-button emulation.

Sourceval set_scroll_button_lock : Wire.Obj.Input.Config.Device.t -> device:string -> bool -> unit

set_scroll_button_lock dev ~device enabled sets scroll-button lock.

Sourceval set_send_events : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Send_events_modes.t -> unit

set_send_events dev ~device mode sets the send-events mode.

Sourceval set_tap_button_map : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Tap_button_map.t -> unit

set_tap_button_map dev ~device map sets the tap button order.

Sourceval set_clickfinger_button_map : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Clickfinger_button_map.t -> unit

set_clickfinger_button_map dev ~device map sets the clickfinger button order.

Sourceval set_click_method : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Click_method.t -> unit

set_click_method dev ~device method_ sets the click method.

Sourceval set_scroll_method : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Scroll_method.t -> unit

set_scroll_method dev ~device method_ sets the scroll method.

Sourceval set_accel_profile : Wire.Obj.Input.Config.Device.t -> device:string -> Wire.Libinput.Accel_profile.t -> unit

set_accel_profile dev ~device profile sets the acceleration profile.

Sourceval set_accel_speed : Wire.Obj.Input.Config.Device.t -> device:string -> float -> unit

set_accel_speed dev ~device speed sets the acceleration speed, in -1, 1.

Sourceval set_scroll_button : Wire.Obj.Input.Config.Device.t -> device:string -> int32 -> unit

set_scroll_button dev ~device button sets the on-button-down scroll button to the Linux input-event code button.

Sourceval set_scroll_factor : Wire.Obj.Input.Management.Device.t -> float -> unit

set_scroll_factor device factor scales the scroll speed of device by factor. factor must not be negative.

Sourceval destroy_libinput_device : Wire.Obj.Input.Config.Device.t -> unit

destroy_libinput_device device destroys the device object.