package oxbow

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file cmd_window_move_to.ml

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
open! Oxbow_ipc

let command_term =
  let open Cmdliner.Term.Syntax in
  let+ x =
    Ctl_cli.extent_pos
      0
      ~docv:"X"
      ~doc:
        "The $(i,X) position of the window's top-left corner, measured from the left of \
         the output's usable area. A pixel offset (e.g. $(b,100)) or a percentage of the \
         usable width (e.g. $(b,25%) places the left edge a quarter of the way accross)"
  and+ y =
    Ctl_cli.extent_pos
      1
      ~docv:"Y"
      ~doc:
        "The $(i,Y) position of the window's top-left corner, measured from the top of \
         the output's usable area. A pixel offset (e.g. $(b,100)) or a percentage of the \
         usable width/height (e.g. $(b,25%) places the top edge a quarter of the way \
         down)"
  and+ target = Ctl_cli.target_any_window_term in
  Command.Window (Move_to { x; y; target })
;;

let name = "to"
let doc = "Move the target window(s) to point ($(i,X), $(i,Y))"
let cmd, bind_cmd = Ctl_cli.cmd_pair ~name ~doc command_term