Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file river_input_management_v1_client.ml
123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263646566676869707172737475767778798081828384858687888990919293949596979899100101102103104105106107108109110111112113114115116117118119120121122123124125126127128129130131132133134135136137138139140141142143144145146147148149150151152153154155156157158159160161162163164165166167168169170171172173174175176177178179180181182183184185186187188189190191192193194195196197198199200201202203204205206207208209210211212213214215216217218219220221222223224225226227228229230231232233234235236237238239240241242243244245246247248249250251252253254255256257258259260261262263264265266267268269270271272273274275276277278279280281282283284285286287288289290291292293294295296297298299300301302303304305306307308309310311312313314315316317318319320321322323324325326327328329330331332333334335336337338339340341342343344345346347348349350351352353354355356357358359360361362363364365366367368369370371372373374375376377378379380381382(* This file was generated automatically by wayland-scanner-ocaml *)[@@@ocaml.warning"-27-34"]openstructmoduleImports=structincludeRiver_input_management_v1_protoincludeWayland.Wayland_protoendmoduleProxy=Wayland.ProxymoduleMsg=Wayland.MsgmoduleFixed=Wayland.FixedmoduleIface_reg=Wayland.Iface_regmoduleS=Wayland.Send(** Input manager global interface.
Input manager global interface. *)moduleRiver_input_manager_v1=structtype'vt=([`River_input_manager_v1],'v,[`Client])Proxy.tmoduleError=River_input_management_v1_proto.River_input_manager_v1.Error(** {2 Version 1, 2} *)(** Destroy a seat.
Destroy the seat with the given name. Has no effect if a seat with the
given name does not exist.
The default seat with name "default" cannot be destroyed and attempting
to destroy it will have no effect.
Any input devices assigned to the destroyed seat at the time of
destruction are assigned to the default seat. *)letdestroy_seat(_t:([<`V1|`V2]as'v)t)~name=let_msg=Proxy.alloc_t~op:3~ints:1~strings:[(Somename)]~arrays:[]inMsg.add_string_msgname;Proxy.send_t_msg(** Create a new seat.
Create a new seat with the given name. Has no effect if a seat with the
given name already exists.
The default seat with name "default" always exists and does not need to
be explicitly created. *)letcreate_seat(_t:([<`V1|`V2]as'v)t)~name=let_msg=Proxy.alloc_t~op:2~ints:1~strings:[(Somename)]~arrays:[]inMsg.add_string_msgname;Proxy.send_t_msg(** Destroy the river_input_manager_v1 object.
This request should be called after the finished event has been received
to complete destruction of the object.
It is a protocol error to make this request before the finished event
has been received.
If a client wishes to destroy this object it should send a
river_input_manager_v1.stop request and wait for a
river_input_manager_v1.finished event. Once the finished event is
received it is safe to destroy this object and any other objects created
through this interface. *)letdestroy(_t:([<`V1|`V2]as'v)t)=let_msg=Proxy.alloc_t~op:1~ints:0~strings:[]~arrays:[]inProxy.send_t_msg;Proxy.shutdown_send_t(** Stop sending events.
This request indicates that the client no longer wishes to receive
events on this object.
The Wayland protocol is asynchronous, which means the server may send
further events until the stop request is processed. The client must wait
for a river_input_manager_v1.finished event before destroying this
object. *)letstop(_t:([<`V1|`V2]as'v)t)=let_msg=Proxy.alloc_t~op:0~ints:0~strings:[]~arrays:[]inProxy.send_t_msg(**/**)classvirtual['v]_handlers_unsafe=object(_self:(_,'v,_)#Proxy.Handler.t)methoduser_data=S.No_datamethodmetadata=(moduleRiver_input_management_v1_proto.River_input_manager_v1)methodmax_version=2lmethodprivatevirtualon_finished:[>]t->unitmethodprivatevirtualon_input_device:[>]t->([`River_input_device_v1],'v,[`Client])Proxy.t->unitmethoddispatch(_proxy:'vt)_msg=let_proxy=Proxy.cast_version_proxyinmatchMsg.op_msgwith|0->_self#on_finished_proxy|1->letid:([`River_input_device_v1],_,_)Proxy.t=Msg.get_int_msg|>Proxy.Handler.accept_new_proxy(moduleImports.River_input_device_v1)in_self#on_input_device_proxyid|_->assertfalseend(**/**)(** {2 Handlers}
Note: Servers will always want to use [v1].
*)(** Handler for a proxy with version >= 1. *)classvirtual['v]v1=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V1|`V2]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_finished:[>`V1|`V2]t->unit(** The server has finished with the input manager.
This event indicates that the server will send no further events on this
object. The client should destroy the object. See
river_input_manager_v1.destroy for more information. *)methodprivatevirtualon_input_device:[>`V1|`V2]t->([`River_input_device_v1],'v,[`Client])Proxy.t->unit(** New input device.
A new input device has been created. *)methodmin_version=1lmethodbind_version:[`V1]=`V1end(** Handler for a proxy with version >= 2. *)classvirtual['v]v2=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V2]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_finished:[>`V2]t->unit(** The server has finished with the input manager.
This event indicates that the server will send no further events on this
object. The client should destroy the object. See
river_input_manager_v1.destroy for more information. *)methodprivatevirtualon_input_device:[>`V2]t->([`River_input_device_v1],'v,[`Client])Proxy.t->unit(** New input device.
A new input device has been created. *)methodmin_version=2lmethodbind_version:[`V2]=`V2endend(** An input device.
An input device represents a physical keyboard, mouse, touchscreen, or
drawing tablet tool. It is assigned to exactly one seat at a time.
By default, all input devices are assigned to the default seat. *)moduleRiver_input_device_v1=structtype'vt=([`River_input_device_v1],'v,[`Client])Proxy.tmoduleError=River_input_management_v1_proto.River_input_device_v1.ErrormoduleType=River_input_management_v1_proto.River_input_device_v1.Type(** {2 Version 1} *)(** Map input device to the given rectangle.
Map the input device to the given rectangle in the global compositor
coordinate space. Has no effect if the device is not a pointer, touch,
or tablet device.
If mapped to both an output and a rectangle, the rectangle has priority.
Width and height must be greater than or equal to 0.
Passing 0 for width or height clears an existing mapping. *)letmap_to_rectangle(_t:([<`V1|`V2]as'v)t)~x~y~width~height=let_msg=Proxy.alloc_t~op:5~ints:4~strings:[]~arrays:[]inMsg.add_int_msgx;Msg.add_int_msgy;Msg.add_int_msgwidth;Msg.add_int_msgheight;Proxy.send_t_msg(** Map input device to the given output.
Map the input device to the given output. Has no effect if the device is
not a pointer, touch, or tablet device.
If mapped to both an output and a rectangle, the rectangle has priority.
Passing null clears an existing mapping. *)letmap_to_output(_t:([<`V1|`V2]as'v)t)~(output:([`Wl_output],_,[`Client])Proxy.toption)=let_msg=Proxy.alloc_t~op:4~ints:1~strings:[]~arrays:[]inMsg.add_int_msg(Proxy.id_optoutput);Proxy.send_t_msg(** Set scroll factor.
Set the scroll factor for a pointer input device. Has no effect if the
device is not a pointer.
For example, a factor of 0.5 will make scrolling twice as slow while a
factor of 3.0 will make scrolling 3 times as fast.
Setting a scroll factor less than 0 is a protocol error. *)letset_scroll_factor(_t:([<`V1|`V2]as'v)t)~factor=let_msg=Proxy.alloc_t~op:3~ints:1~strings:[]~arrays:[]inMsg.add_fixed_msgfactor;Proxy.send_t_msg(** Set keyboard repeat rate and delay.
Set repeat rate and delay for a keyboard input device. Has no effect if
the device is not a keyboard.
Negative values for either rate or delay are illegal. A rate of zero
will disable any repeating (regardless of the value of delay). *)letset_repeat_info(_t:([<`V1|`V2]as'v)t)~rate~delay=let_msg=Proxy.alloc_t~op:2~ints:2~strings:[]~arrays:[]inMsg.add_int_msgrate;Msg.add_int_msgdelay;Proxy.send_t_msg(** Assign the input device to a seat.
Assign the input device to a seat. All input devices not explicitly
assigned to a seat are considered assigned to the default seat.
Has no effect if a seat with the given name does not exist. *)letassign_to_seat(_t:([<`V1|`V2]as'v)t)~name=let_msg=Proxy.alloc_t~op:1~ints:1~strings:[(Somename)]~arrays:[]inMsg.add_string_msgname;Proxy.send_t_msg(** Destroy the input device object.
This request indicates that the client will no longer use the input
device object and that it may be safely destroyed. *)letdestroy(_t:([<`V1|`V2]as'v)t)=let_msg=Proxy.alloc_t~op:0~ints:0~strings:[]~arrays:[]inProxy.send_t_msg;Proxy.shutdown_send_t(** {2 Version 2} *)(**/**)classvirtual['v]_handlers_unsafe=object(_self:(_,'v,_)#Proxy.Handler.t)methoduser_data=S.No_datamethodmetadata=(moduleRiver_input_management_v1_proto.River_input_device_v1)methodmax_version=2lmethodprivatevirtualon_removed:[>]t->unitmethodprivatevirtualon_type:[>]t->type_:Imports.River_input_device_v1.Type.t->unitmethodprivatevirtualon_name:[>]t->name:string->unitmethodprivatevirtualon_done:[>]t->unitmethoddispatch(_proxy:'vt)_msg=let_proxy=Proxy.cast_version_proxyinmatchMsg.op_msgwith|0->_self#on_removed_proxy|1->lettype_=Msg.get_int_msg|>Imports.River_input_device_v1.Type.of_int32in_self#on_type_proxy~type_|2->letname=Msg.get_string_msgin_self#on_name_proxy~name|3->_self#on_done_proxy|_->assertfalseend(**/**)(** {2 Handlers}
Note: Servers will always want to use [v1].
*)(** Handler for a proxy with version >= 1. *)classvirtual['v]v1=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V1|`V2]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_removed:[>`V1|`V2]t->unit(** The input device is removed.
This event indicates that the input device has been removed.
The server will send no further events on this object and ignore any
request (other than river_input_device_v1.destroy) made after this event is
sent. The client should destroy this object with the
river_input_device_v1.destroy request to free up resources. *)methodprivatevirtualon_type:[>`V1|`V2]t->type_:Imports.River_input_device_v1.Type.t->unit(** The type of the input device.
The type of the input device. This event is sent once when the
river_input_device_v1 object is created. The device type cannot
change during the lifetime of the object. *)methodprivatevirtualon_name:[>`V1|`V2]t->name:string->unit(** The name of the input device.
The name of the input device. This event is sent once when the
river_input_device_v1 object is created. The device name cannot
change during the lifetime of the object. *)methodprivatevirtualon_done:[>`V2]t->unit(** All information has been sent.
This event is sent after all information about the input device has
been sent.
This allows changes to one or more river_input_device_v1 properties to
be seen as atomic, even if they happen via multiple events. *)methodmin_version=1lend(** Handler for a proxy with version >= 2. *)classvirtual['v]v2=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V2]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_removed:[>`V2]t->unit(** The input device is removed.
This event indicates that the input device has been removed.
The server will send no further events on this object and ignore any
request (other than river_input_device_v1.destroy) made after this event is
sent. The client should destroy this object with the
river_input_device_v1.destroy request to free up resources. *)methodprivatevirtualon_type:[>`V2]t->type_:Imports.River_input_device_v1.Type.t->unit(** The type of the input device.
The type of the input device. This event is sent once when the
river_input_device_v1 object is created. The device type cannot
change during the lifetime of the object. *)methodprivatevirtualon_name:[>`V2]t->name:string->unit(** The name of the input device.
The name of the input device. This event is sent once when the
river_input_device_v1 object is created. The device name cannot
change during the lifetime of the object. *)methodprivatevirtualon_done:[>`V2]t->unit(** All information has been sent.
This event is sent after all information about the input device has
been sent.
This allows changes to one or more river_input_device_v1 properties to
be seen as atomic, even if they happen via multiple events. *)methodmin_version=2lendend