Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Source file river_layer_shell_v1_client.ml
123456789101112131415161718192021222324252627282930313233343536373839404142434445464748495051525354555657585960616263646566676869707172737475767778798081828384858687888990919293949596979899100101102103104105106107108109110111112113114115116117118119120121122123124125126127128129130131132133134135136137138139140141142143144145146147148149150151152153154155156157158159160161162163164165166167168169170171172173174175176177178179180181182183184185186187188189190191192193194195196197198199200201202203204205206207208209210211212213214215216217218219220221222223224225226227228229230231232233234235236237238239240241242243244245246247248249250251252253254255256257258259260261262263264265266267268269270271272273274275276277278279280281282283284285286287288289(* This file was generated automatically by wayland-scanner-ocaml *)[@@@ocaml.warning"-27-34"]openstructmoduleImports=structincludeRiver_layer_shell_v1_protoincludeRiver_window_management_v1_protoendmoduleProxy=Wayland.ProxymoduleMsg=Wayland.MsgmoduleFixed=Wayland.FixedmoduleIface_reg=Wayland.Iface_regmoduleS=Wayland.Send(** River layer shell global interface.
This global interface should only be advertised to the client if the
river_window_manager_v1 global is also advertised. Binding this interface
indicates that the window manager supports layer shell.
If the window manager does not bind this interface, the compositor should
not allow clients to map layer surfaces. This can be achieved by
closing layer surfaces immediately. *)moduleRiver_layer_shell_v1=structtype'vt=([`River_layer_shell_v1],'v,[`Client])Proxy.tmoduleError=River_layer_shell_v1_proto.River_layer_shell_v1.Error(** {2 Version 1} *)(** Get layer shell seat state.
It is a protocol error to make this request more than once for a given
river_seat_v1 object. *)letget_seat(_t:([<`V1]as'v)t)(id:([`River_layer_shell_seat_v1],'v,[`Client])#Proxy.Handler.t)~(seat:([`River_seat_v1],_,[`Client])Proxy.t)=let__id=Proxy.spawn_tidinlet_msg=Proxy.alloc_t~op:2~ints:2~strings:[]~arrays:[]inMsg.add_int_msg(Proxy.id__id);Msg.add_int_msg(Proxy.idseat);Proxy.send_t_msg;__id(** Get layer shell output state.
It is a protocol error to make this request more than once for a given
river_output_v1 object. *)letget_output(_t:([<`V1]as'v)t)(id:([`River_layer_shell_output_v1],'v,[`Client])#Proxy.Handler.t)~(output:([`River_output_v1],_,[`Client])Proxy.t)=let__id=Proxy.spawn_tidinlet_msg=Proxy.alloc_t~op:1~ints:2~strings:[]~arrays:[]inMsg.add_int_msg(Proxy.id__id);Msg.add_int_msg(Proxy.idoutput);Proxy.send_t_msg;__id(** Destroy the river_layer_shell_v1 object.
This request indicates that the client will no longer use the
river_layer_shell_v1 object. *)letdestroy(_t:([<`V1]as'v)t)=let_msg=Proxy.alloc_t~op:0~ints:0~strings:[]~arrays:[]inProxy.send_t_msg;Proxy.shutdown_send_t(**/**)class['v]_handlers_unsafe=object(_self:(_,'v,_)#Proxy.Handler.t)methoduser_data=S.No_datamethodmetadata=(moduleRiver_layer_shell_v1_proto.River_layer_shell_v1)methodmax_version=1lmethoddispatch(_proxy:'vt)_msg=let_proxy=Proxy.cast_version_proxyinmatchMsg.op_msgwith|_->assertfalseend(**/**)(** {2 Handlers}
Note: Servers will always want to use [v1].
*)(** Handler for a proxy with version >= 1. *)class['v]v1=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V1]as'v]_handlers_unsafe(**/**)methodmin_version=1lmethodbind_version:[`V1]=`V1endend(** Layer shell output state.
The lifetime of this object is tied to the corresponding river_output_v1.
This object is made inert when the river_output_v1.removed event is sent
and should be destroyed. *)moduleRiver_layer_shell_output_v1=structtype'vt=([`River_layer_shell_output_v1],'v,[`Client])Proxy.t(** {2 Version 1} *)(** Set default output for layer surfaces.
Mark this output as the default for new layer surfaces which do not
request a specific output themselves. This request overrides any
previous set_default request on any river_layer_shell_output_v1 object.
If no set_default request is made or if the default output is destroyed,
the default output is undefined until the next set_default request.
This request modifies window management state and may only be made as
part of a manage sequence, see the river_window_manager_v1 description. *)letset_default(_t:([<`V1]as'v)t)=let_msg=Proxy.alloc_t~op:1~ints:0~strings:[]~arrays:[]inProxy.send_t_msg(** Destroy the object.
This request indicates that the client will no longer use the
river_layer_shell_output_v1 object and that it may be safely destroyed.
This request should be made after the river_output_v1.removed event is
received to complete destruction of the output. *)letdestroy(_t:([<`V1]as'v)t)=let_msg=Proxy.alloc_t~op:0~ints:0~strings:[]~arrays:[]inProxy.send_t_msg;Proxy.shutdown_send_t(**/**)classvirtual['v]_handlers_unsafe=object(_self:(_,'v,_)#Proxy.Handler.t)methoduser_data=S.No_datamethodmetadata=(moduleRiver_layer_shell_v1_proto.River_layer_shell_output_v1)methodmax_version=1lmethodprivatevirtualon_non_exclusive_area:[>]t->x:int32->y:int32->width:int32->height:int32->unitmethoddispatch(_proxy:'vt)_msg=let_proxy=Proxy.cast_version_proxyinmatchMsg.op_msgwith|0->letx=Msg.get_int_msginlety=Msg.get_int_msginletwidth=Msg.get_int_msginletheight=Msg.get_int_msgin_self#on_non_exclusive_area_proxy~x~y~width~height|_->assertfalseend(**/**)(** {2 Handlers}
Note: Servers will always want to use [v1].
*)(** Handler for a proxy with version >= 1. *)classvirtual['v]v1=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V1]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_non_exclusive_area:[>`V1]t->x:int32->y:int32->width:int32->height:int32->unit(** Area left after subtracting exclusive zones.
This event indicates the area of the output remaining after subtracting
the exclusive zones of layer surfaces. Exclusive zones are a hint, the
window manager is free to ignore this area hint if it wishes.
The x and y values are in the global coordinate space, not relative to
the position of the output.
This event will be followed by a manage_start event after all other new
state has been sent by the server. *)methodmin_version=1lendend(** Layer shell seat state.
The lifetime of this object is tied to the corresponding river_seat_v1.
This object is made inert when the river_seat_v1.removed event is sent and
should be destroyed. *)moduleRiver_layer_shell_seat_v1=structtype'vt=([`River_layer_shell_seat_v1],'v,[`Client])Proxy.t(** {2 Version 1} *)(** Destroy the object.
This request indicates that the client will no longer use the
river_layer_shell_seat_v1 object and that it may be safely destroyed.
This request should be made after the river_seat_v1.removed event is
received to complete destruction of the seat. *)letdestroy(_t:([<`V1]as'v)t)=let_msg=Proxy.alloc_t~op:0~ints:0~strings:[]~arrays:[]inProxy.send_t_msg;Proxy.shutdown_send_t(**/**)classvirtual['v]_handlers_unsafe=object(_self:(_,'v,_)#Proxy.Handler.t)methoduser_data=S.No_datamethodmetadata=(moduleRiver_layer_shell_v1_proto.River_layer_shell_seat_v1)methodmax_version=1lmethodprivatevirtualon_focus_exclusive:[>]t->unitmethodprivatevirtualon_focus_non_exclusive:[>]t->unitmethodprivatevirtualon_focus_none:[>]t->unitmethoddispatch(_proxy:'vt)_msg=let_proxy=Proxy.cast_version_proxyinmatchMsg.op_msgwith|0->_self#on_focus_exclusive_proxy|1->_self#on_focus_non_exclusive_proxy|2->_self#on_focus_none_proxy|_->assertfalseend(**/**)(** {2 Handlers}
Note: Servers will always want to use [v1].
*)(** Handler for a proxy with version >= 1. *)classvirtual['v]v1=object(_:(_,'v,_)#Proxy.Service_handler.t)(**/**)inherit[[<`V1]as'v]_handlers_unsafe(**/**)methodprivatevirtualon_focus_exclusive:[>`V1]t->unit(** Layer shell surface has exclusive focus.
A layer shell surface will be given exclusive keyboard focus at the end
of the manage sequence in which this event is sent. The window manager
may want to update window decorations or similar to indicate that no
window is focused.
Until the focus_non_exclusive or focus_none event is sent, all window
manager requests to change focus are ignored.
This event will be followed by a manage_start event after all other new
state has been sent by the server. *)methodprivatevirtualon_focus_non_exclusive:[>`V1]t->unit(** Layer shell surface wants non-exclusive focus.
A layer shell surface will be given non-exclusive keyboard focus at the
end of the manage sequence in which this event is sent. The window
manager may want to update window decorations or similar to indicate
that no window is focused.
The window manager continues to control focus and may choose to focus a
different window/shell surface at any time. If the window manager sets
focus during the same manage sequence in which this event is sent, the
layer surface will not be focused.
If the layer surface with non-exclusive focus is closed or the window
manager chooses to move focus away from the layer surface, a focus_none
event will be sent in the next manage sequence.
This event will be followed by a manage_start event after all other new
state has been sent by the server. *)methodprivatevirtualon_focus_none:[>`V1]t->unit(** No layer shell surface has focus.
No layer shell surface will have keyboard focus at the end of the manage
sequence in which this event is sent. The window manager may want to
return focus to whichever window last had focus, for example.
This event will be followed by a manage_start event after all other new
state has been sent by the server. *)methodmin_version=1lendend